############ Script tasks ############ 
setwd("/Users/nicolasmenzie/Google Drive/Harvard/Shanghai TB modelling/ShanghaiTB_6-22/3-Calibration")

#1 load parameter table
#2 calculate implied prior hyper-parameters
#3 create functions for priors, and some random draws

######################################
library(mvtnorm)

hyper_pars <- read.csv("param_init_shanghai_V1.csv")

###  Estimate hyperparameters for priors

# Function for calculating gamma parameters 
gammapar <- function(tgt) {
  tgt <- as.numeric(tgt)
  mn <- tgt[1]; cir <- (tgt[3]-tgt[2])
  xopt <- function(b,mn,cir) {
    cir2 <- qgamma(c(1,39)/40,mn*b,b); cir2 <- cir2[2]-cir2[1]
    (cir2-cir)^2 }
  zz <- optimize(xopt,c(0.1,100000),mn=mn,cir=cir)$minimum 
  c(zz*mn,zz) }

# Function for calculating beta parameters 
betapar <- function(tgt) {
  tgt <- as.numeric(tgt)
  mn <- tgt[1]; cir <- (tgt[3]-tgt[2])
  xopt <- function(xx,mn=mn,cir=cir) {
    cir2 <- qbeta(c(1,39)/40,xx*(mn/(1-mn)),xx); cir2 <- cir2[2]-cir2[1]
    sum((cir2-cir)^2) }
  zz <- optimize(xopt,c(0.2,100000),mn=mn,cir=cir)$minimum
  bp <-  c(zz*(mn/(1-mn)),zz)
  if(sum(abs(bp-1))<0.2) { c(1,1) } else { bp }  }

# Calculate hyper-priors
hyper_pars$hp_1 <- hyper_pars$hp_2 <- NA

for(i in 1:nrow(hyper_pars)){
  if(hyper_pars[i,5]==0) hyper_pars[i,8:9] <- betapar(hyper_pars[i,2:4]) 
  if(hyper_pars[i,5]==1) hyper_pars[i,8:9] <- gammapar(hyper_pars[i,2:4]) 
  if(hyper_pars[i,5]==2) hyper_pars[i,8:9] <- c(hyper_pars[i,2],(hyper_pars[i,4]-hyper_pars[i,3])/3.92)
}

hyper_pars$calib <- as.numeric(hyper_pars$calib_dem==1 | hyper_pars$calib_epi==1)

hyper_pars_c <- hyper_pars[hyper_pars$calib==1,]

####### Draw some starting values from a Normal 

sample.prior <- function(n)  { # n=5
  rmvnorm(n,rep(0,nrow(hyper_pars_c)),diag(rep(1,nrow(hyper_pars_c)))) }

set.seed(1234); init_draws <- sample.prior(n=20) 

####### Create function for calulating prior
idZ0 <- hyper_pars_c$b0_g1_n2==0
idZ1 <- hyper_pars_c$b0_g1_n2==1
idZ2 <- hyper_pars_c$b0_g1_n2==2

# PRIOR
lPrior <- function(P_i) { # P_i = P[hyper_pars$calib==1]
  lDensTrue <- rep(NA,nrow(hyper_pars_c))
  lDensTrue[idZ0] <- dbeta( P_i[idZ0], shape1  = hyper_pars_c[idZ0,8], shape2 = hyper_pars_c[idZ0,9],log=T)
  lDensTrue[idZ1] <- dgamma(P_i[idZ1], shape   = hyper_pars_c[idZ1,8], rate   = hyper_pars_c[idZ1,9],log=T)
  lDensTrue[idZ2] <- dnorm( P_i[idZ2], mean    = hyper_pars_c[idZ2,8], sd     = hyper_pars_c[idZ2,9],log=T)  
  return( sum(lDensTrue) )
}

## UNTRANSFORM 
untransform_P <- function(tP_i,ids=1:nrow(hyper_pars_c)){ # ids = 1:4; tP_i = pars; # ids of hyper_pars_c
  whc <- hyper_pars_c$b0_g1_n2[ids]
  idZz <- list(ids[whc==0], ids[whc==1], ids[whc==2])
    # norm2unif
  P_i <- P_i0 <- pnorm(tP_i,0,1)
  # unif2true
  P_i[whc==0] <- qbeta( P_i0[whc==0], shape1  = hyper_pars_c[idZz[[1]],8], shape2 = hyper_pars_c[idZz[[1]],9])
  P_i[whc==1] <- qgamma(P_i0[whc==1], shape   = hyper_pars_c[idZz[[2]],8], rate   = hyper_pars_c[idZz[[2]],9])
  P_i[whc==2] <- qnorm( P_i0[whc==2], mean    = hyper_pars_c[idZz[[3]],8], sd     = hyper_pars_c[idZz[[3]],9])  
  return( P_i )
}

# Initial values for P
P_init <- hyper_pars$point_est; names(P_init) <- hyper_pars$par_name

# ResNam
ResNam <- c("Year",                                  # year
            paste("MortRes",1:20,sep="_"),           # 
            paste("MortMig",1:20,sep="_"),           # 
            paste("TotRes",1:20,sep="_"),            # 
            paste("TotResMale",1:20,sep="_"),        # 
            paste("TotResFemale",1:20,sep="_"),      # 
            paste("TotMig",1:20,sep="_"),            # 
            paste("TotMigMale",1:20,sep="_"),        # 
            paste("TotMigFemale",1:20,sep="_"),      # 
            paste("TotIncidResMale",1:20,sep="_"),   # 
            paste("TotIncidResFemale",1:20,sep="_"), # 
            paste("TotIncidMigMale",1:20,sep="_"),   # 
            paste("TotIncidMigFemale",1:20,sep="_"), # 
            paste("Case",1:20,sep="_"),              # 
            paste("Fatality",1:20,sep="_"),          # 
            paste("TotNotifResMale",1:20,sep="_"),   # 
            paste("TotNotifResFemale",1:20,sep="_"), # 
            paste("TotNotifMigMale",1:20,sep="_"),   # 
            paste("TotNotifMigFemale",1:20,sep="_"), # 
            paste("DurImm",1:5,sep="_"),             # 
                  "Mortl",                           # 
                  "NotifRes",                        # 
                  "NotifMig",                        # 
            paste("PInfMigIfMig",1:20,sep="_"),      #  
            paste("PInfMigIfRes",1:20,sep="_"),      #  
            paste("RtMigFromRes",1:20,sep="_"),      #  
            paste("RtMigFromMig",1:20,sep="_"),      # 
            paste("RtResFromRes",1:20,sep="_"),      # 
            paste("RtResFromMig",1:20,sep="_"),      #
            paste("TotTbDthResMale",1:20,sep="_"),   # 
            paste("TotTbDthResFemale",1:20,sep="_"), # 
            paste("TotTbDthMigMale",1:20,sep="_"),   # 
            paste("TotTbDthMigFemale",1:20,sep="_"), # 
            paste("TotTbNltResMale",1:20,sep="_"),   # 
            paste("TotTbNltResFemale",1:20,sep="_"), # 
            paste("TotTbNltMigMale",1:20,sep="_"),   # 
            paste("TotTbNltMigFemale",1:20,sep="_"), # 
            paste("TotTbFoiResMale",1:20,sep="_"),   # 
            paste("TotTbFoiResFemale",1:20,sep="_"), # 
            paste("TotTbFoiMigMale",1:20,sep="_"),   # 
            paste("TotTbFoiMigFemale",1:20,sep="_"),  # 
            paste("RtIncidResMale",1:20,sep="_"),   # 
            paste("RtIncidResFemale",1:20,sep="_"), # 
            paste("RtIncidMigMale",1:20,sep="_"),   # 
            paste("RtIncidMigFemale",1:20,sep="_"), # 
            paste("ImpCaseResMale",1:20,sep="_"),   # 
            paste("ImpCaseResFemale",1:20,sep="_"), # 
            paste("ImpCaseMigMale",1:20,sep="_"),   # 
            paste("ImpCaseMigFemale",1:20,sep="_") # 
            )
    length(ResNam)       

save(hyper_pars,hyper_pars_c,lPrior,idZ0,idZ1,idZ2,init_draws,untransform_P,P_init,ResNam,file="prior_objects_11_21_2019.rData")

### ADDITIONAL PARAMETERS
hyper_pars_addn <- read.csv("param_addn_shanghai_V1.csv")

# Calculate hyper-priors
hyper_pars_addn$hp_2 <- hyper_pars_addn$hp_1 <- NA

for(i in 1:nrow(hyper_pars_addn)){
  if(hyper_pars_addn[i,5]==0) hyper_pars_addn[i,6:7] <- betapar(hyper_pars_addn[i,2:4]) 
  if(hyper_pars_addn[i,5]==1) hyper_pars_addn[i,6:7] <- gammapar(hyper_pars_addn[i,2:4]) 
  if(hyper_pars_addn[i,5]==2) hyper_pars_addn[i,6:7] <- c(hyper_pars_addn[i,2],(hyper_pars_addn[i,4]-hyper_pars_addn[i,3])/3.92)
}

# sample values
samp_addn_pars <- matrix(NA,1000,nrow(hyper_pars_addn))
colnames(samp_addn_pars) <- hyper_pars_addn$par_name
set.seed(123)
for(i in 1:nrow(hyper_pars_addn)){
  samp_addn_pars[,i] <- rbeta(1000,hyper_pars_addn$hp_1[i],hyper_pars_addn$hp_2[i])
}
#

save(samp_addn_pars,hyper_pars_addn,file="addn_parameter_draws_10_31_2019.rData")





