############ Script tasks ############ 

#1 define a function that takes parameters and other input values, and creates all objects needed for model

######################################

# libraries
library(splines)

# some helper functions
lgt <-  function(x) log(x/(1-x));  invlgt <- function(x) 1/(1+exp(-x))  # defined some convenience functions for logit and inverse logit NAM
spline_design_mat <- as.matrix(as.data.frame(bs(1:18 , df=5, degree=2, intercept=T))) # create b-spline basis function with 18 points for 18 years and 5 parameters
spline_design_age <- as.matrix(as.data.frame(bs(0:19/19,knots=c(23,34)/100,degree=2,intercept=T))) #  b-spline basis with 20 points, 5 parameters, weighted towards distribution

make_obj_for_sim <- function(P,imm_scen,bur_scen,sc_i){
  # sc_i not yet used
  
  O <- list()
  #  ~~~~~ demographic parameters ~~~~~
  O$p_Male        <- P["p_Male"]             # 0.51618 # Proportion of male for new borns
  Imm0            <- exp( spline_design_mat%*%P[grep("mig_spln",names(P))] ) # monthly mig trend
  O$Imm <- c(Imm0,c(Imm0[18]*c(1.0,0.95,1.05)[imm_scen]^seq(1:40)))  ##~~~
  O$emig_rate     <- P["emig_rate"]/12      # monthly emigration rate
  O$PrImm         <- PrMiSex0 
  O$PrImm[,1]     <- O$PrImm[,1] * exp( spline_design_age%*%P[grep("mig_age_spln",names(P))] )
  O$PrImm[,2]     <- O$PrImm[,2] * exp( spline_design_age%*%P[grep("mig_age_spln",names(P))] )
  O$PrImm         <- O$PrImm/sum(O$PrImm)
  O$ResMove       <- exp( spline_design_mat%*%P[grep("res_spln",names(P))] )[c(1:18,rep(18,40))] # monthly resident inflow ##~~~

  #  ~~~~~ TB parameters ~~~~~  
  O$rrmuTb_smrn   <-  P["rrmuTb_smrn"]        # 0.5                          # rate ratio of TB mortality for smr neg
  rrInfect_Iz     <-  P["rrInfect_Iz"]        # 0.6
  rrInfect_In     <-  P["rrInfect_In"]        # 0.23
  O$rrInfect      <-  c(0,0,0,0,rrInfect_Iz,rrInfect_In,1,0,0)    # relative infectivity of different health states
  O$rrpfastPI     <-  P["rrpfastPI"]          # 0.21                         # partial immunity LTBI
  O$rRecov        <-  P["rRecov"]/12          # 0.03/12                      # rate of Ls -> I
  O$rSlfCur       <-  P["rSlfCur"]/12         # 0.2/12
  O$rProgress     <-  P["rProgress"]/12       # 3/12
  O$pSmrP         <-  P["pSmrP"]              # 0.4
  O$rSmrConv      <-  P["rSmrConv"]/12        # 0.15/12
  O$rrSenst       <-  P["rrSenst"]            # 0.75  
  O$rComplete     <-  P["rComplete"]/12       # 2/12
  O$rDefault      <-  P["rDefault"]/12        # 0.439/12
  O$Txeff         <-  P["Txeff"]              #  0.96
  O$muTb          <-  P["muTb"]/12
  O$rrmuTb_trt    <-  P["rrmuTb_trt"]
  meanCR          <-  P["meanCR"]/12
  rrCRag20        <-  P["rrCRag20"]
  rel_cont_ag     <-  rowSums(cont_mat)
  cont_mat2       <-  cont_mat
  for(i in 1:20) cont_mat2[,i] <- cont_mat[,i]/ (colSums(cont_mat)/rel_cont_ag)
  rrAgeCR         <-  rel_cont_ag*c(rep(1,4),rep(rrCRag20,2),rep(1,14))
  O$effCR         <-  meanCR*rrAgeCR/mean(rrAgeCR)
  cont_mat3       <- cont_mat2
  cont_mat3[5:6,5:6] <-  cont_mat2[5:6,5:6]+sum(rrAgeCR-rel_cont_ag)/2
  O$cont_mat0     <-  as.matrix(cont_mat3)  #  ~~~~~~~~~~ NEW
  O$rrFemCR       <-  P["rrFemCR"]
  O$rrMigCR       <-  P["rrMigCR"]
  O$alpha         <-  P["alpha"]
  rrTB_fem0       <-  P["rrTB_fem0"]
  rrTB_age0       <-  P["rrTB_age0"]*c(rep(0,9),1:11 / 11)
  rrTB_age_fem0   <-  P["rrTB_age_fem0"]*c(rep(0,9),1:11 / 11)
  O$pfast_ag      <-  invlgt( lgt(P["pfast"]) + rrTB_age0 )
  O$pfast_agF     <-  invlgt( lgt(P["pfast"]) + rrTB_age_fem0 + rrTB_fem0 )
  O$rfast         <-  P["rfast"]/12
  O$rslow_ag      <-  exp( log(P["rslow"]) + rrTB_age0 )/12
  O$rslow_agF     <-  exp( log(P["rslow"]) + rrTB_age_fem0 + rrTB_fem0 )/12
  O$rDiag         <-  P["rDiag"]/12
  O$dDetect       <-  P["dDetect"]/12
  rrmuTb_age0     <-  P["rrmuTb_age"]^c(rep(0,4),1:16 / 16)
  O$rrmuTb_age    <-  rrmuTb_age0/mean(rrmuTb_age0)
  O$rrDiagMi      <-  c(1,rep(P["rrDiagMi"],4))
  O$rrImmActive   <-  P["rrImmActive"]
  O$scale_up      <- c(rep(0,20*12),seq(0,1,length.out=24),rep(1,36*12)) ##~~~
  O$decl_entr_tb  <- c(0.03,0.00,0.06)[bur_scen]
  
  return(O) 
}


