
library(Rcpp) 

StatList <- noquote(list(c(paste(0:18*5,0:18*5+4,sep="_"),"95p"),
                         c("Su","Sp","Ls","Lf","Iz","In","Ip","Fn","Fp"), c("Male","Female"),
                         c("Non",paste(0:2*5,0:2*5+4,sep="_"),"15p")))    
names(StatList) <- c("age_cats","tb_cats","sex","migrant_dur")
# StatList 

#############

cppFunction('
  List cModel(
    int                 nYrs,
    NumericMatrix       InitPopAgeSex,     /// Resident Population stratified by age and sex
    NumericMatrix       InitMig,           /// Migrant Population stratified by age and sex
    std::vector<double> InitPrDur,         /// Initial proportion of duration for migrants
    std::vector<double> Birthst,           /// Monthly birth rate
    double              p_Male,            /// Proportion of male for new borns
    NumericMatrix       PrRes,             /// Proportion of Resident inflow stratified by age and sex    
    std::vector<double> ResMove,
    std::vector<double> Imm,               /// Monthly immigration population
    NumericMatrix       PrImm,             /// Proportion of Immigration population stratified by age and sex
    double              emig_rate,          /// Monthly emigration rate
    std::vector<double> BgMort,            /// Monthly mortality rate
    NumericMatrix       rrMort,            /// Relative risk of mortality stratified by age and sex
    double              muTb,
    double              rrmuTb_smrn,
    double              rrmuTb_trt,
    std::vector<double> rrmuTb_age,
    std::vector<double> pfast_ag,
    std::vector<double> pfast_agF,
    double              rrpfastPI,
    std::vector<double> rslow_ag,
    std::vector<double> rslow_agF,
    double              rfast,
    double              rrImmActive,
    double              rSlfCur,
    std::vector<double> effCR,            /// Monthly contact rates
    NumericMatrix       cont_mat0,        /// Contact matrix adj for pop size
    double              rrFemCR,          /// Relative contact rate for female vs. male
    double              rrMigCR,          /// Relative contact rate for migrants vs. residents
    std::vector<double> rrInfect,         /// Rate of infecting people per contact
    double              alpha,            /// Weights in foi
    double              rRecov,
    double              pSmrP,
    double              rSmrConv,
    double              rProgress,
    double              rDiag,
    double              dDetect,
    std::vector<double> rrDiagMi,
    double              rrSenst,          /// Sensitivity of diagnosis for smear negative
    double              rDefault,
    double              rComplete,
    double              Txeff,
    double              nRes,
    double              Int1,
    double              Int2,
    double              Int3,
    double              Int4,
    double              Int5,
    std::vector<double> scale_up,
    double              incr_sens,
    double              p_cure_ipt,
    double              p_tx_tb_scr,
    std::vector<double> mig_manuf_const,
    double              rel_sens_e,
    double              decl_entr_tb
  ){  
    
    /////////////////////////////////////////////////////////////////////////////
      //// CREATED INTERNALLY 
    int           s;
    double        temp;
    double        temp1;
    double        temp2;
    double        temp3;
    double        temp4;
    double        pop_ag_mg[20][3];      
    double        inf_ag_mg[20][3];   
    double        P_Inf_ag[20][3];      
    double        cont_mat0ZR[20][20];      
    double        cont_mat0ZM[20][20];      
    double        cont_mat0ZB[20][20];      
    double        cont_mat0ZR_sum[20];
    double        cont_mat0ZM_sum[20];
    double        cont_mat0ZB_sum[20];
    double        P_inf_mig_if_mig[20];
    double        P_inf_mig_if_res[20];
    double        p_tbRes[20][9][2];
    double        p_tbImm[20][9][2];
    double        p_tbRes2019[20][9][2];
    double        p_tbImm2019[20][9][2];
    double        tempRes[20][2];
    double        tempMig[20][2];
    double        Sum_p_tbImm[20][2];
    double        foi[20][5][2];
    double        V0[20][9][2][5];        
    double        V1[20][9][2][5];
    double        BurnResZ[20][2];        
    double        BurnMigZ[20][2];      
    double        InitPopAgeSexZ[InitPopAgeSex.nrow()][InitPopAgeSex.ncol()]; 
    double        InitMigZ[InitMig.nrow()][InitMig.ncol()];
    double        PrResZ[PrRes.nrow()][PrRes.ncol()];
    double        PrImmZ[PrImm.nrow()][PrImm.ncol()];
    double        rrMortZ[rrMort.nrow()][rrMort.ncol()];
    double        cont_mat0Z[cont_mat0.nrow()][cont_mat0.ncol()];

    NumericMatrix Trace(nYrs,20*9*2*5);
    NumericMatrix Out(nYrs,nRes);
    
    //// INITIALIZE 
    for(int i=0; i<nYrs; i++){ for(int j=0; j<nRes; j++){ Out(i,j) = 0; } }
    for(int i=0; i<InitPopAgeSex.nrow(); i++){ for(int j=0; j<InitPopAgeSex.ncol(); j++){ InitPopAgeSexZ[i][j] = InitPopAgeSex(i,j); } }
    for(int i=0; i<InitMig.nrow(); i++){ for(int j=0; j<InitMig.ncol(); j++){ InitMigZ[i][j] = InitMig(i,j); } }  
    for(int i=0; i<PrRes.nrow(); i++){ for(int j=0; j<PrRes.ncol(); j++){ PrResZ[i][j] = PrRes(i,j); } }
    for(int i=0; i<PrImm.nrow(); i++){ for(int j=0; j<PrImm.ncol(); j++){ PrImmZ[i][j] = PrImm(i,j); } }
    for(int i=0; i<rrMort.nrow(); i++){ for(int j=0; j<rrMort.ncol(); j++){ rrMortZ[i][j] = rrMort(i,j); } } 
    for(int i=0; i<cont_mat0.nrow(); i++){ for(int j=0; j<cont_mat0.ncol(); j++){ cont_mat0Z[i][j] = cont_mat0(i,j); } } 
    
    for(int ag=0; ag<20; ag++){ for(int tb=0; tb<9; tb++){
        for(int sx=0; sx<2; sx++){ for(int ms=0; ms<5; ms++){
            V0[ag][tb][sx][ms]= 0;   V1[ag][tb][sx][ms] = 0;   } } } }

    /////////////////////////////////////////////////////////////////////////////// 
      //// BURN IN  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      /// Populate model
    for(int ag=0; ag<20; ag++){
      for(int sx=0; sx<2; sx++)
      {
        V0[ag][0][sx][0] = InitPopAgeSexZ[ag][sx]*0.50;  
        V0[ag][2][sx][0] = InitPopAgeSexZ[ag][sx]*0.50;
        for(int ms=1; ms<5; ms++)
        {
          V0[ag][0][sx][ms] = InitMigZ[ag][sx]*InitPrDur[ms]*0.50; 
          V0[ag][2][sx][ms] = InitMigZ[ag][sx]*InitPrDur[ms]*0.50;
        }
      } 
    } 
    
    for(int ag=0; ag<20; ag++){ 
      for(int tb=0; tb<9; tb++){
        for(int sx=0; sx<2; sx++){
          for(int ms=0; ms<5; ms++){
            V1[ag][tb][sx][ms] = V0[ag][tb][sx][ms]; 
          }
        }
      }
    }
    
    for(int m=0; m<1200; m++){  // ~~~ start burn in ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        /// BIRTHS ///
        temp = temp1 = 0;
        for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<9; tb++){ 
          tempRes[ag][sx] = tempMig[ag][sx] = Sum_p_tbImm[ag][sx] = 0; 
          p_tbRes[ag][tb][sx] = p_tbImm[ag][tb][sx] = 0; } }}
        
        for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<9; tb++){ for(int ms=0; ms<5; ms++){
          if(ms==0){
            temp            += V0[ag][tb][sx][ms]; }        /// Total population of residents
          else {
            temp1           += V0[ag][tb][sx][ms]; }        /// Total population of migrants
        } } } }   
        
        V1[0][0][0][0]  += Birthst[0]*temp*p_Male;  
        V1[0][0][1][0]  += Birthst[0]*temp*(1-p_Male);
        V1[0][0][0][1]  += Birthst[0]*temp1*p_Male;         /// Assume equal birth rate for migrants
        V1[0][0][1][1]  += Birthst[0]*temp1*(1-p_Male);
        
        /// IMMIGRATION + RESIDENTS MOVE-IN ///
          for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<7; tb++){ for(int ms=0; ms<5; ms++){
            if(ms==0){
              tempRes[ag][sx] += V0[ag][tb][sx][ms];
            } else {
              tempMig[ag][sx] += V0[ag][tb][sx][ms];          
            } } } } }        /// Total population for tb in [0,6]
        
        for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<7; tb++){ 
          p_tbRes[ag][tb][sx] = V0[ag][tb][sx][0]/tempRes[ag][sx];
          for(int ms=1; ms<5; ms++){
            p_tbImm[ag][tb][sx] += V0[ag][tb][sx][ms]/tempMig[ag][sx]; }
        } }}
        
        for(int ag=0; ag<20; ag++){                 /// Assume no entrants are on treatment
          for(int sx=0; sx<2; sx++){
            p_tbRes[ag][7][sx] = p_tbRes[ag][8][sx] = 0;
            p_tbImm[ag][7][sx] = p_tbImm[ag][8][sx] = 0;
            p_tbImm[ag][4][sx] = p_tbImm[ag][4][sx]*rrImmActive;
            p_tbImm[ag][5][sx] = p_tbImm[ag][5][sx]*rrImmActive;
            p_tbImm[ag][6][sx] = p_tbImm[ag][6][sx]*rrImmActive;
          }
        }
        
        //// Normalize p_tbImm
        for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<7; tb++){ 
          Sum_p_tbImm[ag][sx] += p_tbImm[ag][tb][sx]; }
        } }
        
        for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<7; tb++){ 
          p_tbImm[ag][tb][sx] = p_tbImm[ag][tb][sx]/Sum_p_tbImm[ag][sx]; }
        } }
        
        for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<9; tb++){ 
          V1[ag][tb][sx][1]  += Imm[0]*PrImmZ[ag][sx]*p_tbImm[ag][tb][sx]; 
          V1[ag][tb][sx][0]  += ResMove[0]*PrResZ[ag][sx]*p_tbRes[ag][tb][sx]; } } }
        
        /// EMIGRATION /// 
          for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<9; tb++){ for(int ms=1; ms<5; ms++){
            V1[ag][tb][sx][ms] -= emig_rate*V0[ag][tb][sx][ms]; } } } }
        
        /// MORTALITY ///
          for(int ag=0; ag<20; ag++){          
            for(int sx=0; sx<2; sx++){ 
              for(int ms=0; ms<5; ms++){ 
                for(int tb=0; tb<9; tb++){
                  if(tb<5){
                    V1[ag][tb][sx][ms] -= V0[ag][tb][sx][ms]*(BgMort[0]*rrMortZ[ag][sx]);
                  }
                  if(tb==5){               /// Smear positive
                    V1[ag][tb][sx][ms] -= V0[ag][tb][sx][ms]*(BgMort[0]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag]);
                  }
                  if(tb==6){              /// Smear negative
                    V1[ag][tb][sx][ms] -= V0[ag][tb][sx][ms]*(BgMort[0]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag]*rrmuTb_smrn);
                  }
                  if(tb>6){     /// Treatment
                    V1[ag][tb][sx][ms] -= V0[ag][tb][sx][ms]*(BgMort[0]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag]*rrmuTb_trt);
                  }
                }
              }
            }
          }
        
        /// AGING ///
          temp = 0;
        for(int ag=0; ag<19; ag++){ 
          for(int tb=0; tb<9; tb++){
            for(int sx=0; sx<2; sx++){  
              for(int ms=0; ms<5; ms++){
                temp = V0[ag][tb][sx][ms]/60;    
                if(ms==0 || ms==4){              /// Residents OR Duration > 15
                  V1[ag  ][tb][sx][ms]  -= temp; 
                  V1[ag+1][tb][sx][ms]  += temp; }
                else {
                  V1[ag  ][tb][sx][ms  ]  -= temp; 
                  V1[ag+1][tb][sx][ms+1]  += temp; }
              }
            }
          }
        }
        
/// Force of infection
  for(int sx=0; sx<2; sx++){ 
  if(sx==0){ temp4 = 1; } else { temp4 = rrFemCR;   }
  for(int ag=0; ag<20; ag++){
    pop_ag_mg[ag][0] = pop_ag_mg[ag][1] = pop_ag_mg[ag][2] = 0;
    inf_ag_mg[ag][0] = inf_ag_mg[ag][1] = inf_ag_mg[ag][2] = 0;
    for(int tb=0; tb<9; tb++){
     for(int ms=0; ms<5; ms++){
      if(ms==0){ 
        pop_ag_mg[ag][0] +=  V0[ag][tb][0][ms]*temp4;
        inf_ag_mg[ag][0] +=  V0[ag][tb][0][ms]*rrInfect[tb]*temp4;
        pop_ag_mg[ag][2] +=  V0[ag][tb][0][ms]*temp4;
        inf_ag_mg[ag][2] +=  V0[ag][tb][0][ms]*rrInfect[tb]*temp4;
      } else {
        pop_ag_mg[ag][1] +=  V0[ag][tb][0][ms]*temp4*rrMigCR;
        inf_ag_mg[ag][1] +=  V0[ag][tb][0][ms]*rrInfect[tb]*temp4*rrMigCR;
        pop_ag_mg[ag][2] +=  V0[ag][tb][0][ms]*temp4*rrMigCR;
        inf_ag_mg[ag][2] +=  V0[ag][tb][0][ms]*rrInfect[tb]*temp4*rrMigCR;
      } } } } }

  for(int ag=0; ag<20; ag++){ 
    for(int a2=0; a2<20; a2++){
      cont_mat0ZR[ag][a2] = cont_mat0Z[ag][a2]*pop_ag_mg[a2][0];
      cont_mat0ZM[ag][a2] = cont_mat0Z[ag][a2]*pop_ag_mg[a2][1];
      cont_mat0ZB[ag][a2] = cont_mat0Z[ag][a2]*pop_ag_mg[a2][2];
    }
  }
  for(int ag=0; ag<20; ag++){ 
      cont_mat0ZR_sum[ag] = cont_mat0ZM_sum[ag] = cont_mat0ZB_sum[ag] = 0;
    for(int a2=0; a2<20; a2++){
      cont_mat0ZR_sum[ag] +=  cont_mat0ZR[ag][a2];
      cont_mat0ZM_sum[ag] +=  cont_mat0ZM[ag][a2];
      cont_mat0ZB_sum[ag] +=  cont_mat0ZB[ag][a2];
    }
  }

  for(int ag=0; ag<20; ag++){ 
    for(int a2=0; a2<20; a2++){
      cont_mat0ZR[ag][a2] = cont_mat0ZR[ag][a2]/cont_mat0ZR_sum[ag]*effCR[ag];
      cont_mat0ZM[ag][a2] = cont_mat0ZM[ag][a2]/cont_mat0ZM_sum[ag]*effCR[ag];
      cont_mat0ZB[ag][a2] = cont_mat0ZB[ag][a2]/cont_mat0ZB_sum[ag]*effCR[ag];
    }
  }

  for(int ag=0; ag<20; ag++){ 
    P_Inf_ag[ag][0] = 0; P_Inf_ag[ag][1] = 0; P_Inf_ag[ag][2] = 0;
    for(int a2=0; a2<20; a2++){
      P_Inf_ag[ag][0] += cont_mat0ZR[ag][a2]*inf_ag_mg[a2][0]/pop_ag_mg[a2][0];
      P_Inf_ag[ag][1] += cont_mat0ZM[ag][a2]*inf_ag_mg[a2][1]/pop_ag_mg[a2][1];
      P_Inf_ag[ag][2] += cont_mat0ZB[ag][a2]*inf_ag_mg[a2][2]/pop_ag_mg[a2][2];
    }
  }

  for(int ag=0; ag<20; ag++){
    foi[ag][0][0] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][0]);                      /// Residents
    foi[ag][0][1] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][0])*rrFemCR;              /// Female
    for(int ms=1; ms<5; ms++){
      foi[ag][ms][0] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][1])*rrMigCR;           /// Migrants
      foi[ag][ms][1] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][1])*rrFemCR*rrMigCR;   /// Female
    }
  }
        
        ///  INFECTION /// 
          for(int ag=0; ag<20; ag++){ 
            for(int sx=0; sx<2; sx++){
              if(sx==0){ temp3 = pfast_ag[ag]; } else { temp3 = pfast_agF[ag]; }
              for(int ms=0; ms<5; ms++){
                temp = V0[ag][0][sx][ms]*foi[ag][ms][sx];  // Su
                V1[ag][0][sx][ms]  -= temp; 
                V1[ag][2][sx][ms]  += temp*(1-temp3); 
                V1[ag][3][sx][ms]  += temp*temp3;
                // SUPER-INFECTION SP
                temp = V0[ag][1][sx][ms]*foi[ag][ms][sx];  // Sp
                V1[ag][1][sx][ms]  -= temp; 
                V1[ag][2][sx][ms]  += temp*(1-rrpfastPI*temp3);  
                V1[ag][3][sx][ms]  += temp*rrpfastPI*temp3; 
                // SUPER-INFECTION LS
                temp = V0[ag][2][sx][ms]*foi[ag][ms][sx]*(rrpfastPI*temp3);  // Ls
                V1[ag][2][sx][ms]  -= temp; 
                V1[ag][3][sx][ms]  += temp;  
              }  
            }
          }
        
        /// BREAKDOWN ///  
          for(int ag=0; ag<20; ag++){
            for(int sx=0; sx<2; sx++){   
              if(sx==0){ temp4 = rslow_ag[ag]; } else { temp4 = rslow_agF[ag]; }
              for(int ms=0; ms<5; ms++){
                temp  = V0[ag][2][sx][ms]*temp4;
                temp2 = V0[ag][3][sx][ms]*rfast;      
                V1[ag][2][sx][ms]  -= temp; 
                V1[ag][3][sx][ms]  -= temp2; 
                V1[ag][4][sx][ms]  += (temp+temp2);
                
                temp1 = V0[ag][4][sx][ms]*rProgress*(1-pSmrP);
                temp3 = V0[ag][4][sx][ms]*rProgress*pSmrP;
                V1[ag][5][sx][ms]  += temp1; 
                V1[ag][6][sx][ms]  += temp3; 
                V1[ag][4][sx][ms]  -= (temp1+temp3);
              }
            }
          }
        
        /// LATENT SLOW TO SAFE ///  
          for(int ag=0; ag<20; ag++){
            for(int sx=0; sx<2; sx++){
              for(int ms=0; ms<5; ms++){
                temp = V0[ag][2][sx][ms]*rRecov;
                V1[ag][2][sx][ms]  -= temp;
                V1[ag][1][sx][ms]  += temp;  
              }   
            }
          }
        /// SMEAR CONVERSION ///
          for(int ag=0; ag<20; ag++){  
            for(int sx=0; sx<2; sx++){ 
              for(int ms=0; ms<5; ms++){
                temp = V0[ag][5][sx][ms]*rSmrConv;
                V1[ag][5][sx][ms]  -= temp; 
                V1[ag][6][sx][ms]  += temp;
              }
            }
          }
        
        /// SELF-CURE/// 
          for(int ag=0; ag<20; ag++){
            for(int sx=0; sx<2; sx++){
              for(int ms=0; ms<5; ms++){
                for(int tb=4; tb<7; tb++){
                  temp = V0[ag][tb][sx][ms]*rSlfCur;
                  V1[ag][tb][sx][ms]  -= temp; 
                  V1[ag][2 ][sx][ms]  += temp;
                }
              }   
            }
          }
        
        /// TB DIAGNOSIS AND TX INITIATION ///
          for(int ag=0; ag<20; ag++){
            for(int sx=0; sx<2; sx++){
              for(int ms=0; ms<5; ms++){
                temp  = V0[ag][5][sx][ms]*rDiag*pow(1+dDetect,(m-1199))*rrDiagMi[ms]*rrSenst;
                temp2 = V0[ag][6][sx][ms]*rDiag*pow(1+dDetect,(m-1199))*rrDiagMi[ms];
                V1[ag][5 ][sx][ms]  -= temp; 
                V1[ag][6 ][sx][ms]  -= temp2;
                V1[ag][7 ][sx][ms]  += temp;
                V1[ag][8 ][sx][ms]  += temp2;
              }   
            }
          }
        
        /// TB TREATMENT OUTCOMES ///  
          for(int ag=0; ag<20; ag++){
            for(int sx=0; sx<2; sx++){
              for(int ms=0; ms<5; ms++){
                // Cures
                temp  = V0[ag][7 ][sx][ms]*rComplete*Txeff;
                temp1 = V0[ag][8 ][sx][ms]*rComplete*Txeff;
                V1[ag][7 ][sx][ms]  -= temp; 
                V1[ag][8 ][sx][ms]  -= temp1;
                V1[ag][2 ][sx][ms]  += (temp+temp1); 
                // Failures
                temp2 = V0[ag][7 ][sx][ms]*(rDefault+rComplete*(1-Txeff));
                temp3 = V0[ag][8 ][sx][ms]*(rDefault+rComplete*(1-Txeff));
                V1[ag][7 ][sx][ms]  -= temp2; 
                V1[ag][8 ][sx][ms]  -= temp3;
                V1[ag][5 ][sx][ms]  += temp2;
                V1[ag][6 ][sx][ms]  += temp3;
              }   
            }
          }
        
        /// RESET POP SIZE ///
          for(int ag=0; ag<20; ag++){
            for(int sx=0; sx<2; sx++){ 
              BurnResZ[ag][sx] = 0; 
              BurnMigZ[ag][sx] = 0;  
            }
          }
        
        for(int ag=0; ag<20; ag++){ 
          for(int sx=0; sx<2; sx++){
            for(int tb=0; tb<9; tb++){
              BurnResZ[ag][sx] += V1[ag][tb][sx][0];          /// Total residents
              for(int ms=1; ms<5; ms++){
                BurnMigZ[ag][sx] += V1[ag][tb][sx][ms];       /// Total immigrants
              }
            } 
          }
        }
        for(int ag=0; ag<20; ag++){ 
          for(int sx=0; sx<2; sx++){ 
            BurnResZ[ag][sx] = InitPopAgeSexZ[ag][sx]/BurnResZ[ag][sx];
            BurnMigZ[ag][sx] = InitMigZ[ag][sx]/BurnMigZ[ag][sx];  
          }
        }
        for(int ag=0; ag<20; ag++){                          /// reset pop to InitPopAge
          for(int sx=0; sx<2; sx++){  
            for(int tb=0; tb<9; tb++){
              V1[ag][tb][sx][0]  = V1[ag][tb][sx][0]*BurnResZ[ag][sx];
              V0[ag][tb][sx][0]  = V1[ag][tb][sx][0];
              for(int ms=1; ms<5; ms++){ 
                V1[ag][tb][sx][ms]  = V1[ag][tb][sx][ms]*BurnMigZ[ag][sx];
                V0[ag][tb][sx][ms]  = V1[ag][tb][sx][ms];
              }
            }   
          }
        }
    }  //  ~~~ end burn in ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      
      /////////////////////////////////////////////////////////////////////////////// 
      //// YEAR LOOP  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      for(int y=0; y<nYrs; y++){
        //// MONTH LOOP  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
          for(int m=0; m<12; m++){  
            s = y*12+m; // counter of months since start
            
            /// BIRTHS ///
              temp = temp1 = 0;
              for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<9; tb++){ 
                tempRes[ag][sx] = tempMig[ag][sx] = Sum_p_tbImm[ag][sx] = 0; 
                p_tbRes[ag][tb][sx] = p_tbImm[ag][tb][sx] = 0; } }}
              
              for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<9; tb++){ for(int ms=0; ms<5; ms++){
                if(ms==0){ 
                  temp            += V0[ag][tb][sx][ms]; }        /// Total population of residents
                else {
                  temp1           += V0[ag][tb][sx][ms]; }        /// Total population of migrants
              } } } }   
              
              V1[0][0][0][0]  += Birthst[y]*temp*p_Male;  
              V1[0][0][1][0]  += Birthst[y]*temp*(1-p_Male);
              V1[0][0][0][1]  += Birthst[y]*temp1*p_Male;    
              V1[0][0][1][1]  += Birthst[y]*temp1*(1-p_Male);
              
              /// IMMIGRATION + RESIDENTS MOVE-IN ///
                for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<7; tb++){ for(int ms=0; ms<5; ms++){
                  if(ms==0){
                    tempRes[ag][sx] += V0[ag][tb][sx][ms];
                  } else {
                    tempMig[ag][sx] += V0[ag][tb][sx][ms];          
                  } } } } }        /// Total population for tb in [0,6]
              
              for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<7; tb++){ 
                p_tbRes[ag][tb][sx] = V0[ag][tb][sx][0]/tempRes[ag][sx];
                for(int ms=1; ms<5; ms++){
                  p_tbImm[ag][tb][sx] += V0[ag][tb][sx][ms]/tempMig[ag][sx]; } } }}
              
              for(int ag=0; ag<20; ag++){                 /// Add on-treatment entrants back into the Ls compartment
                for(int sx=0; sx<2; sx++){
                  p_tbRes[ag][7][sx] = p_tbRes[ag][8][sx] = 0;
                  p_tbImm[ag][7][sx] = p_tbImm[ag][8][sx] = 0;
                  p_tbImm[ag][4][sx] = p_tbImm[ag][4][sx]*rrImmActive;
                  p_tbImm[ag][5][sx] = p_tbImm[ag][5][sx]*rrImmActive;
                  p_tbImm[ag][6][sx] = p_tbImm[ag][6][sx]*rrImmActive;
                }
              }
              
              //// Normalize p_tbImm
              for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<7; tb++){ 
                Sum_p_tbImm[ag][sx] += p_tbImm[ag][tb][sx]; } }}
              
              for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<7; tb++){ 
                p_tbImm[ag][tb][sx] = p_tbImm[ag][tb][sx]/Sum_p_tbImm[ag][sx]; } }}

              //// Save p_tbImm and p_tbRes for later (end 2019)
              if(s==239){
              for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<9; tb++){ 
              p_tbImm2019[ag][tb][sx] = p_tbImm[ag][tb][sx];
              p_tbRes2019[ag][tb][sx] = p_tbRes[ag][tb][sx]; } } } }

              if(s>239){
              temp = pow(1-decl_entr_tb,(s-239.0)/12);
              for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){
              temp1 = temp2 = 0;
              for(int tb=2; tb<9; tb++){ 
                p_tbImm[ag][tb][sx] = p_tbImm2019[ag][tb][sx]*temp;
                p_tbRes[ag][tb][sx] = p_tbRes2019[ag][tb][sx]*temp;
                temp1 += p_tbImm2019[ag][tb][sx]*(1-temp);
                temp2 += p_tbRes2019[ag][tb][sx]*(1-temp);
              }
              p_tbImm[ag][0][sx] = p_tbImm2019[ag][0][sx] + temp1;
              p_tbImm[ag][1][sx] = p_tbImm2019[ag][1][sx];
              p_tbRes[ag][0][sx] = p_tbRes2019[ag][0][sx] + temp2;
              p_tbRes[ag][1][sx] = p_tbRes2019[ag][1][sx];
              } } }

              for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){
                V1[ag][0][sx][1]  += Imm[y]*PrImmZ[ag][sx]*p_tbImm[ag][0][sx]; 
                V1[ag][1][sx][1]  += Imm[y]*PrImmZ[ag][sx]*(p_tbImm[ag][1][sx]+(p_tbImm[ag][2][sx]+p_tbImm[ag][3][sx])*Int4*scale_up[s]*p_cure_ipt); 
                V1[ag][2][sx][1]  += Imm[y]*PrImmZ[ag][sx]*p_tbImm[ag][2][sx]*(1-Int4*scale_up[s]*p_cure_ipt); 
                V1[ag][3][sx][1]  += Imm[y]*PrImmZ[ag][sx]*p_tbImm[ag][3][sx]*(1-Int4*scale_up[s]*p_cure_ipt); 
                V1[ag][4][sx][1]  += Imm[y]*PrImmZ[ag][sx]*p_tbImm[ag][4][sx]*(1-Int3*scale_up[s]*p_tx_tb_scr*rel_sens_e); 
                V1[ag][5][sx][1]  += Imm[y]*PrImmZ[ag][sx]*p_tbImm[ag][5][sx]*(1-Int3*scale_up[s]*p_tx_tb_scr); 
                V1[ag][6][sx][1]  += Imm[y]*PrImmZ[ag][sx]*p_tbImm[ag][6][sx]*(1-Int3*scale_up[s]*p_tx_tb_scr); 
                V1[ag][7][sx][1]  += Imm[y]*PrImmZ[ag][sx]*(p_tbImm[ag][7][sx]+(p_tbImm[ag][4][sx]*rel_sens_e+p_tbImm[ag][5][sx])*Int3*scale_up[s]*p_tx_tb_scr); 
                V1[ag][8][sx][1]  += Imm[y]*PrImmZ[ag][sx]*(p_tbImm[ag][8][sx]+p_tbImm[ag][6][sx]*Int3*scale_up[s]*p_tx_tb_scr); 
                for(int tb=0; tb<9; tb++){
                  V1[ag][tb][sx][0]  += ResMove[y]*PrResZ[ag][sx]* p_tbRes[ag][tb][sx]; } } }
              
              /// EMIGRATION /// 
                for(int ag=0; ag<20; ag++){ for(int sx=0; sx<2; sx++){ for(int tb=0; tb<9; tb++){ for(int ms=1; ms<5; ms++){
                  V1[ag][tb][sx][ms] -= emig_rate*V0[ag][tb][sx][ms]; } } } }
              
              /// MORTALITY ///
                for(int ag=0; ag<20; ag++){ 
                  for(int sx=0; sx<2; sx++){ 
                    for(int ms=0; ms<5; ms++){ 
                      for(int tb=0; tb<9; tb++){
                        if(tb<5){
                          V1[ag][tb][sx][ms] -= V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx]);
                         }
                        if(tb==5){               /// Smear positive
                          V1[ag][tb][sx][ms] -= V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag]);
                        }
                        if(tb==6){               /// Smear negative
                          V1[ag][tb][sx][ms] -= V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag]*rrmuTb_smrn);
                        }
                        if(tb>6){      /// Treatment
                          V1[ag][tb][sx][ms] -= V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag]*rrmuTb_trt);
                        }
                      }
                    }
                  }
                }
              
              /// AGING ///
                for(int ag=0; ag<19; ag++){ 
                  for(int tb=0; tb<9; tb++){
                    for(int sx=0; sx<2; sx++){
                      for(int ms=0; ms<5; ms++){
                        temp = V0[ag][tb][sx][ms]/60;    
                        if(ms==0 || ms==4){              /// Residents OR Duration > 15 
                          V1[ag  ][tb][sx][ms]  -= temp; 
                          V1[ag+1][tb][sx][ms]  += temp; }
                        else {
                          V1[ag  ][tb][sx][ms  ]  -= temp; 
                          V1[ag+1][tb][sx][ms+1]  += temp; }
                      }
                    }
                  }
                }
              
  /// Force of infection
  for(int sx=0; sx<2; sx++){ 
    if(sx==0){temp4 = 1; } else { temp4 = rrFemCR;   }
    for(int ag=0; ag<20; ag++){
      pop_ag_mg[ag][0] = pop_ag_mg[ag][1] = pop_ag_mg[ag][2] = 0;
      inf_ag_mg[ag][0] = inf_ag_mg[ag][1] = inf_ag_mg[ag][2] = 0;
      for(int tb=0; tb<9; tb++){
        for(int ms=0; ms<5; ms++){
          if(ms==0){ 
          pop_ag_mg[ag][0] +=  V0[ag][tb][0][ms]*temp4;
          inf_ag_mg[ag][0] +=  V0[ag][tb][0][ms]*rrInfect[tb]*temp4;
          pop_ag_mg[ag][2] +=  V0[ag][tb][0][ms]*temp4;
          inf_ag_mg[ag][2] +=  V0[ag][tb][0][ms]*rrInfect[tb]*temp4;
        } else {
          pop_ag_mg[ag][1] +=  V0[ag][tb][0][ms]*temp4*rrMigCR;
          inf_ag_mg[ag][1] +=  V0[ag][tb][0][ms]*rrInfect[tb]*temp4*rrMigCR;
          pop_ag_mg[ag][2] +=  V0[ag][tb][0][ms]*temp4*rrMigCR;
          inf_ag_mg[ag][2] +=  V0[ag][tb][0][ms]*rrInfect[tb]*temp4*rrMigCR;
        } } } } }
            
  for(int ag=0; ag<20; ag++){ 
    for(int a2=0; a2<20; a2++){
      cont_mat0ZR[ag][a2] = cont_mat0Z[ag][a2]*pop_ag_mg[a2][0];
      cont_mat0ZM[ag][a2] = cont_mat0Z[ag][a2]*pop_ag_mg[a2][1];
      cont_mat0ZB[ag][a2] = cont_mat0Z[ag][a2]*pop_ag_mg[a2][2];
      } }
  
  for(int ag=0; ag<20; ag++){ 
    cont_mat0ZR_sum[ag] = cont_mat0ZM_sum[ag] = cont_mat0ZB_sum[ag] = 0;
    for(int a2=0; a2<20; a2++){
      cont_mat0ZR_sum[ag] +=  cont_mat0ZR[ag][a2];
      cont_mat0ZM_sum[ag] +=  cont_mat0ZM[ag][a2];
      cont_mat0ZB_sum[ag] +=  cont_mat0ZB[ag][a2];
    } }
       
  for(int ag=0; ag<20; ag++){ 
    for(int a2=0; a2<20; a2++){
      cont_mat0ZR[ag][a2] = cont_mat0ZR[ag][a2]/cont_mat0ZR_sum[ag]*effCR[ag];
      cont_mat0ZM[ag][a2] = cont_mat0ZM[ag][a2]/cont_mat0ZM_sum[ag]*effCR[ag];
      cont_mat0ZB[ag][a2] = cont_mat0ZB[ag][a2]/cont_mat0ZB_sum[ag]*effCR[ag];
    } }
            
for(int ag=0; ag<20; ag++){ 
  P_Inf_ag[ag][0] = 0; P_Inf_ag[ag][1] = 0; P_Inf_ag[ag][2] = 0;
  for(int a2=0; a2<20; a2++){
    P_Inf_ag[ag][0] += cont_mat0ZR[ag][a2]*inf_ag_mg[a2][0]/pop_ag_mg[a2][0];
    P_Inf_ag[ag][1] += cont_mat0ZM[ag][a2]*inf_ag_mg[a2][1]/pop_ag_mg[a2][1];
    P_Inf_ag[ag][2] += cont_mat0ZB[ag][a2]*inf_ag_mg[a2][2]/pop_ag_mg[a2][2];
  } }
            
  for(int ag=0; ag<20; ag++){
    foi[ag][0][0] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][0]);                      /// Residents
    foi[ag][0][1] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][0])*rrFemCR;              /// Female
    for(int ms=1; ms<5; ms++){
      foi[ag][ms][0] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][1])*rrMigCR;           /// Migrants
      foi[ag][ms][1] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][1])*rrFemCR*rrMigCR;   /// Female
    } }
              
///  INFECTION /// 
                for(int ag=0; ag<20; ag++){
                  for(int sx=0; sx<2; sx++){
                  if(sx==0){ temp3 = pfast_ag[ag]; } else { temp3 = pfast_agF[ag]; }
                    for(int ms=0; ms<5; ms++){
                      temp = V0[ag][0][sx][ms]*foi[ag][ms][sx];  // Su
                      V1[ag][0][sx][ms]  -= temp; 
                      V1[ag][2][sx][ms]  += temp*(1-temp3); 
                      V1[ag][3][sx][ms]  += temp*temp3;
                      // SUPER-INFECTION SP
                      temp = V0[ag][1][sx][ms]*foi[ag][ms][sx];  // Sp
                      V1[ag][1][sx][ms]  -= temp; 
                      V1[ag][2][sx][ms]  += temp*(1-temp3*rrpfastPI); 
                      V1[ag][3][sx][ms]  += temp*temp3*rrpfastPI; 
                      // SUPER-INFECTION LS
                      temp = V0[ag][2][sx][ms]*foi[ag][ms][sx]*temp3*rrpfastPI;  // Ls
                      V1[ag][2][sx][ms]  -= temp; 
                      V1[ag][3][sx][ms]  += temp; 
                    }
                  } 
                }
              
              /// BREAKDOWN ///  
                for(int ag=0; ag<20; ag++){ 
                  for(int sx=0; sx<2; sx++){ 
                  if(sx==0){ temp4 = rslow_ag[ag]; } else { temp4 = rslow_agF[ag]; }
                    for(int ms=0; ms<5; ms++){
                      temp  = V0[ag][2][sx][ms]*temp4;
                      temp2 = V0[ag][3][sx][ms]*rfast;
                      V1[ag][3][sx][ms]  -= temp2;
                      V1[ag][4][sx][ms]  += (temp+temp2);
                      temp1 = V0[ag][4][sx][ms]*rProgress*(1-pSmrP);
                      temp3 = V0[ag][4][sx][ms]*rProgress*pSmrP;
                      V1[ag][5][sx][ms]  += temp1; 
                      V1[ag][6][sx][ms]  += temp3; 
                      V1[ag][4][sx][ms]  -= (temp1+temp3);
                    }
                  }   
                }
              
              /// LATENT SLOW TO SAFE ///  
                for(int ag=0; ag<20; ag++){
                  for(int sx=0; sx<2; sx++){
                    for(int ms=0; ms<5; ms++){ 
                      temp = V0[ag][2][sx][ms]*rRecov;
                      V1[ag][2][sx][ms] -= temp;
                      V1[ag][1][sx][ms] += temp; 
                    }   
                  }
                }
              
              /// SMEAR CONVERSION ///
                for(int ag=0; ag<20; ag++){  
                  for(int sx=0; sx<2; sx++){ 
                    for(int ms=0; ms<5; ms++){
                      temp = V0[ag][5][sx][ms]*rSmrConv;
                      V1[ag][5][sx][ms]  -= temp; 
                      V1[ag][6][sx][ms]  += temp;
                    }
                  }
                }
              
              /// SELF-CURE/// 
                for(int ag=0; ag<20; ag++){
                  for(int sx=0; sx<2; sx++){ 
                    for(int ms=0; ms<5; ms++){
                      for(int tb=4; tb<7; tb++){
                        temp = V0[ag][tb][sx][ms]*rSlfCur;
                        V1[ag][tb][sx][ms]  -= temp; 
                        V1[ag][2 ][sx][ms]  += temp;
                      }
                    }      
                  } 
                }
              
              /// TB DIAGNOSIS AND TX INITIATION ///
                for(int ag=0; ag<20; ag++){
                  for(int sx=0; sx<2; sx++){
                    for(int ms=0; ms<5; ms++){
                      temp  = V0[ag][5][sx][ms]*rDiag*pow(1+dDetect,std::min(s,19*12))*rrDiagMi[ms]*rrSenst;
                      temp2 = V0[ag][6][sx][ms]*rDiag*pow(1+dDetect,std::min(s,19*12))*rrDiagMi[ms];
                      V1[ag][5 ][sx][ms]  -= temp; 
                      V1[ag][6 ][sx][ms]  -= temp2;
                      V1[ag][7 ][sx][ms]  += temp;
                      V1[ag][8 ][sx][ms]  += temp2;
                    }   
                  }
                }

            /// INT 1 ///
            for(int ag=13; ag<20; ag++){
              for(int sx=0; sx<2; sx++){
                temp3 = V0[ag][4][sx][0]*scale_up[s]*Int1*incr_sens*(1.0/12.0);
                temp  = V0[ag][5][sx][0]*scale_up[s]*Int1*incr_sens*(1.0/12.0);
                temp2 = V0[ag][6][sx][0]*scale_up[s]*Int1*incr_sens*(1.0/12.0);
                V1[ag][4 ][sx][0]  -= temp3; 
                V1[ag][5 ][sx][0]  -= temp; 
                V1[ag][6 ][sx][0]  -= temp2;
                V1[ag][7 ][sx][0]  += temp+temp3;
                V1[ag][8 ][sx][0]  += temp2;
              }   
            }

            /// INT 5 ///
            for(int ag=0; ag<20; ag++){
              for(int sx=0; sx<2; sx++){
                for(int ms=1; ms<5; ms++){
                  temp3 = V0[ag][4][sx][ms]*scale_up[s]*Int5*p_tx_tb_scr*mig_manuf_const[ag]*(1.0/12.0)*rel_sens_e;
                  temp  = V0[ag][5][sx][ms]*scale_up[s]*Int5*p_tx_tb_scr*mig_manuf_const[ag]*(1.0/12.0);
                  temp2 = V0[ag][6][sx][ms]*scale_up[s]*Int5*p_tx_tb_scr*mig_manuf_const[ag]*(1.0/12.0);
                  V1[ag][4 ][sx][ms]  -= temp3; 
                  V1[ag][5 ][sx][ms]  -= temp; 
                  V1[ag][6 ][sx][ms]  -= temp2;
                  V1[ag][7 ][sx][ms]  += temp+temp3;
                  V1[ag][8 ][sx][ms]  += temp2;
                }   
              }
            }

            /// INT 2 ///
            for(int ag=13; ag<20; ag++){
              for(int sx=0; sx<2; sx++){
                temp  = V0[ag][2][sx][0]*scale_up[s]*Int2*p_cure_ipt*(0.2/12.0);
                temp2 = V0[ag][3][sx][0]*scale_up[s]*Int2*p_cure_ipt*(0.2/12.0);
                V1[ag][2 ][sx][0]  -= temp; 
                V1[ag][3 ][sx][0]  -= temp2;
                V1[ag][1 ][sx][0]  += temp+temp2;
              }   
            }
              
              /// TB TREATMENT OUTCOMES ///  
                for(int ag=0; ag<20; ag++){
                  for(int sx=0; sx<2; sx++){
                    for(int ms=0; ms<5; ms++){
                      // Cures
                      temp  = V0[ag][7 ][sx][ms]*rComplete*Txeff;
                      temp1 = V0[ag][8 ][sx][ms]*rComplete*Txeff;
                      V1[ag][7 ][sx][ms]  -= temp; 
                      V1[ag][8 ][sx][ms]  -= temp1;
                      V1[ag][2 ][sx][ms]  += (temp+temp1); 
                      // Failures
                      temp2 = V0[ag][7 ][sx][ms]*(rDefault+rComplete*(1-Txeff));
                      temp3 = V0[ag][8 ][sx][ms]*(rDefault+rComplete*(1-Txeff));
                      V1[ag][7 ][sx][ms]  -= temp2; 
                      V1[ag][8 ][sx][ms]  -= temp3;
                      V1[ag][5 ][sx][ms]  += temp2;
                      V1[ag][6 ][sx][ms]  += temp3;
                    }   
                  }
                }
            
            //// MID-YEAR RESULTS ////
            if(m==6){
            /// YEAR
            Out(y,0) = 2001+y;
            //// FILL TRACE
            for(int ag=0; ag<20; ag++){ 
            for(int tb=0; tb<9; tb++){
            for(int sx=0; sx<2; sx++){
            for(int ms=0; ms<5; ms++){
            Trace(y, ag+tb*20+sx*180+ms*360) = V0[ag][tb][sx][ms];   } } } }
            
            /// POPULATION, MORTALITY and FATALITY of Residents /// 
            temp = temp3 = 0;
            for(int ag=0; ag<20; ag++){
            temp1 = temp2 = 0;
            for(int sx=0; sx<2; sx++){
            for(int tb=0; tb<9; tb++){
            for(int ms=0; ms<5; ms++){
            if(ms==0){                 //// Residents
            Out(y,ag+1+20*2) +=  V1[ag][tb][sx][ms];
            temp          +=  V1[ag][tb][sx][ms];                 /// Record total residents to calculate notification rate
            if(sx==0){
            Out(y,ag+1+20*3)   +=  V1[ag][tb][sx][ms]; }
            if(sx==1){
            Out(y,ag+1+20*4) +=  V1[ag][tb][sx][ms]; }
            if(tb<5){
            temp1 += V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx])*12.0; }
            if(tb==5){              /// Smear positive
            temp1 += V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag])*12.0;
            Out(y,ag+1+20*13)  += V0[ag][tb][sx][ms]*muTb*rrmuTb_age[ag]*12.0; }
            if(tb==6){               /// Smear negative
            temp1 += V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag]*rrmuTb_smrn)*12.0;
            Out(y,ag+1+20*13)  += V0[ag][tb][sx][ms]*muTb*rrmuTb_age[ag]*rrmuTb_smrn*12.0; }
            if(tb>6){      /// Treatment
            temp1 += V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag]*rrmuTb_trt)*12.0;
            Out(y,ag+1+20*13)  += V0[ag][tb][sx][ms]*muTb*rrmuTb_age[ag]*rrmuTb_trt*12.0; }

            }
            else {                       //// Migrants
            Out(y,ag+1+20*5) +=  V1[ag][tb][sx][ms];
            temp3         +=  V1[ag][tb][sx][ms];                /// Record total migrants to calculate notification rate
            if(sx==0){
            Out(y,ag+1+20*6)   +=  V1[ag][tb][sx][ms]; }
            if(sx==1){
            Out(y,ag+1+20*7) +=  V1[ag][tb][sx][ms]; }
            if(tb<5){
            temp2 += V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx])*12.0; }
            if(tb==5){               /// Smear positive
            temp2 += V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag])*12.0; }
            if(tb==6){               /// Smear negative
            temp2 += V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag]*rrmuTb_smrn)*12.0; }
            if(tb>6){      /// Treatment
            temp2 += V0[ag][tb][sx][ms]*(BgMort[y]*rrMortZ[ag][sx]+muTb*rrmuTb_age[ag]*rrmuTb_trt)*12.0; }
            }
            } } } 
            Out(y,6+20*18) += (temp1+temp2);
            Out(y,ag+1+20*0) = temp1;
            Out(y,ag+1+20*1) = temp2;
            }
            
            /// NOTIFICATION AND INCIDENCE RATE/// 
            temp1 = temp2 = 0;
            for(int ag=0; ag<20; ag++){
            for(int sx=0; sx<2; sx++){
            if(sx==0){ temp4 = rslow_ag[ag]; } else { temp4 = rslow_agF[ag]; }
            for(int ms=0; ms<5; ms++){
            if(ms==0){
            temp1 = (V0[ag][5][sx][ms]*rDiag*pow(1+dDetect,std::min(s,19*12))*rrSenst + V0[ag][6][sx][ms]*rDiag*pow(1+dDetect,std::min(s,19*12)))*12.0;
            if(ag>12){ temp1 += (V0[ag][4][sx][0] + V0[ag][5][sx][0] + V0[ag][6][sx][0])*scale_up[s]*Int1*incr_sens; }

            Out(y,7+20*18) += temp1/temp;
            Out(y,ag+1+20*12) += V0[ag][4][sx][ms]*rProgress*12.0;
            if(sx==0){
            Out(y,ag+1+20*14)   += temp1;
            Out(y,ag+1+20*8)   += (V0[ag][2][sx][ms]*temp4 + V0[ag][3][sx][ms]*rfast)*12.0;
            Out(y,ag+9+20*36)  += V0[ag][3][sx][ms]*rfast*(1-pow(1-rfast,24.0))*12;
            } else {
            Out(y,ag+1+20*15) += temp1;
            Out(y,ag+1+20*9) += (V0[ag][2][sx][ms]*temp4 + V0[ag][3][sx][ms]*rfast)*12.0;
            Out(y,ag+9+20*37)  += V0[ag][3][sx][ms]*rfast*(1-pow(1-rfast,24.0))*12;
            }    
            } else {
            temp2 = (V0[ag][5][sx][ms]*rDiag*rrDiagMi[ms]*pow(1+dDetect,std::min(s,19*12))*rrSenst + V0[ag][6][sx][ms]*rDiag*rrDiagMi[ms]*pow(1+dDetect,std::min(s,19*12)))*12.0                       
                    + (V0[ag][4][sx][ms]*rel_sens_e + V0[ag][5][sx][ms] + V0[ag][6][sx][ms])*scale_up[s]*Int5*p_tx_tb_scr*mig_manuf_const[ag];
             if(ms==1){ temp2 += Imm[y]*PrImmZ[ag][sx]*((p_tbImm[ag][4][sx]*rel_sens_e+p_tbImm[ag][5][sx]+p_tbImm[ag][6][sx])*Int3*scale_up[s]*p_tx_tb_scr)*12.0; }

            Out(y,8+20*18) += temp2/temp3;
            if(sx==0){
            Out(y,ag+1+20*16)   += temp2;
            Out(y,ag+1+20*10)   += (V0[ag][2][sx][ms]*temp4 + V0[ag][3][sx][ms]*rfast)*12.0;
            Out(y,ag+9+20*38)  += V0[ag][3][sx][ms]*rfast*(1-pow(1-rfast,24.0))*12;
            } else {
            Out(y,ag+1+20*17) += temp2;
            Out(y,ag+1+20*11) += (V0[ag][2][sx][ms]*temp4 + V0[ag][3][sx][ms]*rfast)*12.0;
            Out(y,ag+9+20*39)  += V0[ag][3][sx][ms]*rfast*(1-pow(1-rfast,24.0))*12;
            }
            }
            } } }
            
            /// DURATION OF STAY /// 
            for(int ms=0; ms<5; ms++){
            temp1 = 0;
            for(int sx=0; sx<2; sx++){
            for(int tb=0; tb<9; tb++){
            for(int ag=0; ag<20; ag++){
            temp1 += V0[ag][tb][sx][ms]; } } } 
            Out(y,ms+1+20*18) = temp1/temp3;
            }
            
            for(int ag=0; ag<20; ag++){
            foi[ag][0][0] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][0]);                      /// Residents
            foi[ag][0][1] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][0])*rrFemCR;              /// Female
            for(int ms=1; ms<5; ms++){
            foi[ag][ms][0] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][1])*rrMigCR;           /// Migrants
            foi[ag][ms][1] = (alpha*P_Inf_ag[ag][2]+(1-alpha)*P_Inf_ag[ag][1])*rrFemCR*rrMigCR;   /// Female
            } }
            
            
            /// Force of infection
            for(int ag=0; ag<20; ag++){
            P_inf_mig_if_res[ag] =  (alpha*P_Inf_ag[ag][2] * inf_ag_mg[ag][1]/inf_ag_mg[ag][2] + (1-alpha)*P_Inf_ag[ag][0] * 0) / foi[ag][0][0];
            P_inf_mig_if_mig[ag] =  (alpha*P_Inf_ag[ag][2] * inf_ag_mg[ag][1]/inf_ag_mg[ag][2] + (1-alpha)*P_Inf_ag[ag][1] * 1)*rrMigCR / foi[ag][1][0];
            Out(y,ag+9+20*18) = P_inf_mig_if_mig[ag];
            Out(y,ag+9+20*19) = P_inf_mig_if_res[ag];
            }
            
            ///  INFECTION /// 
            for(int ag=0; ag<20; ag++){
            for(int sx=0; sx<2; sx++){
            if(sx==0){ temp3 = pfast_ag[ag]; } else { temp3 = pfast_agF[ag]; }
            for(int ms=0; ms<5; ms++){
            if(ms==0){
            temp = V0[ag][0][sx][ms]*foi[ag][ms][sx];  // Su
            Out(y,ag+9+20*22)  += temp*temp3 * (1-P_inf_mig_if_res[ag]);
            Out(y,ag+9+20*23)  += temp*temp3 * P_inf_mig_if_res[ag];
            // SUPER-INFECTION SP
            temp = V0[ag][1][sx][ms]*foi[ag][ms][sx];  // Sp
            Out(y,ag+9+20*22)  += temp*temp3*rrpfastPI * (1-P_inf_mig_if_res[ag]);
            Out(y,ag+9+20*23)  += temp*temp3*rrpfastPI * P_inf_mig_if_res[ag];
            // SUPER-INFECTION LS
            temp = V0[ag][2][sx][ms]*foi[ag][ms][sx]*temp3*rrpfastPI;  // Ls
            Out(y,ag+9+20*22)  += temp * (1-P_inf_mig_if_res[ag]); 
            Out(y,ag+9+20*23)  += temp * P_inf_mig_if_res[ag]; 
            } else {
            temp = V0[ag][0][sx][ms]*foi[ag][ms][sx];  // Su
            Out(y,ag+9+20*20)  += temp*temp3 * (1-P_inf_mig_if_mig[ag]);
            Out(y,ag+9+20*21)  += temp*temp3 * P_inf_mig_if_mig[ag];
            // SUPER-INFECTION SP
            temp = V0[ag][1][sx][ms]*foi[ag][ms][sx];  // Sp
            Out(y,ag+9+20*20)  += temp*temp3*rrpfastPI * (1-P_inf_mig_if_mig[ag]);
            Out(y,ag+9+20*21)  += temp*temp3*rrpfastPI * P_inf_mig_if_mig[ag];
            // SUPER-INFECTION LS
            temp = V0[ag][2][sx][ms]*foi[ag][ms][sx]*temp3*rrpfastPI;  // Ls
            Out(y,ag+9+20*20)  += temp * (1-P_inf_mig_if_mig[ag]); 
            Out(y,ag+9+20*21)  += temp * P_inf_mig_if_mig[ag]; 
            }  }  } }

            /// MORTALITY ///
            for(int ag=0; ag<20; ag++){
              for(int sx=0; sx<2; sx++){
                for(int ms=0; ms<5; ms++){ 
                if(sx==0 & ms==0){  Out(y,ag+9+20*24) += (V0[ag][5][sx][ms]*muTb*rrmuTb_age[ag] + 
                                        V0[ag][6][sx][ms]*muTb*rrmuTb_age[ag]*rrmuTb_smrn +
                                       (V0[ag][7][sx][ms] + V0[ag][8][sx][ms])*muTb*rrmuTb_age[ag]*rrmuTb_trt)*12.0;    }
                if(sx==1 & ms==0){  Out(y,ag+9+20*25) += (V0[ag][5][sx][ms]*muTb*rrmuTb_age[ag] + 
                                        V0[ag][6][sx][ms]*muTb*rrmuTb_age[ag]*rrmuTb_smrn +
                                       (V0[ag][7][sx][ms] + V0[ag][8][sx][ms])*muTb*rrmuTb_age[ag]*rrmuTb_trt)*12.0;   }
                if(sx==0 & ms>0){   Out(y,ag+9+20*26) += (V0[ag][5][sx][ms]*muTb*rrmuTb_age[ag] + 
                                        V0[ag][6][sx][ms]*muTb*rrmuTb_age[ag]*rrmuTb_smrn +
                                       (V0[ag][7][sx][ms] + V0[ag][8][sx][ms])*muTb*rrmuTb_age[ag]*rrmuTb_trt)*12.0;    }
                if(sx==1 & ms>0){   Out(y,ag+9+20*27) += (V0[ag][5][sx][ms]*muTb*rrmuTb_age[ag] + 
                                        V0[ag][6][sx][ms]*muTb*rrmuTb_age[ag]*rrmuTb_smrn +
                                       (V0[ag][7][sx][ms] + V0[ag][8][sx][ms])*muTb*rrmuTb_age[ag]*rrmuTb_trt)*12.0;    }
                }
              }
            }

            /// NEW LTBI ///  
            for(int ag=0; ag<20; ag++){
              for(int sx=0; sx<2; sx++){
                for(int ms=0; ms<5; ms++){ 
                if(sx==0 & ms==0){  Out(y,ag+9+20*28) += foi[ag][ms][sx]*(V0[ag][0][sx][ms]+(V1[ag][1][sx][ms]+V0[ag][2][sx][ms])*rrpfastPI)*12.0;   }
                if(sx==1 & ms==0){  Out(y,ag+9+20*29) += foi[ag][ms][sx]*(V0[ag][0][sx][ms]+(V1[ag][1][sx][ms]+V0[ag][2][sx][ms])*rrpfastPI)*12.0;   }
                if(sx==0 & ms>0){   Out(y,ag+9+20*30) += foi[ag][ms][sx]*(V0[ag][0][sx][ms]+(V1[ag][1][sx][ms]+V0[ag][2][sx][ms])*rrpfastPI)*12.0;   }
                if(sx==1 & ms>0){   Out(y,ag+9+20*31) += foi[ag][ms][sx]*(V0[ag][0][sx][ms]+(V1[ag][1][sx][ms]+V0[ag][2][sx][ms])*rrpfastPI)*12.0;   }
                }
              }
            }

            /// FOI /// 
            for(int ag=0; ag<20; ag++){
              for(int ms=0; ms<5; ms++){ 
                for(int tb=4; tb<7; tb++){
                  if(ms==0){  
                    Out(y,ag+9+20*32) += V0[ag][tb][0][ms]*rrInfect[tb]*effCR[ag]*12.0;  
                    Out(y,ag+9+20*33) += V0[ag][tb][1][ms]*rrInfect[tb]*effCR[ag]*rrFemCR*12.0;   
                  } else {
                    Out(y,ag+9+20*34) += V0[ag][tb][0][ms]*rrInfect[tb]*effCR[ag]*rrMigCR*12.0;   
                    Out(y,ag+9+20*35) += V0[ag][tb][1][ms]*rrInfect[tb]*effCR[ag]*rrFemCR*rrMigCR*12.0;   
                  } } } }
        
            /// PREVALENT AT ENTRY /// 

            for(int ag=0; ag<20; ag++){ 
              for(int tb=4; tb<9; tb++){
                Out(y,ag+9+20*40) += ResMove[y]*PrResZ[ag][0]*p_tbRes[ag][tb][0]*12.0;  // male, res
                Out(y,ag+9+20*41) += ResMove[y]*PrResZ[ag][1]*p_tbRes[ag][tb][1]*12.0;  // female, res
                Out(y,ag+9+20*42) += Imm[y]    *PrImmZ[ag][0]*p_tbImm[ag][tb][0]*12.0;  // male, mig
                Out(y,ag+9+20*43) += Imm[y]    *PrImmZ[ag][1]*p_tbImm[ag][tb][1]*12.0;  // female, mig
              } } 

          } //// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ end mid-year results
            
            //// UPDATE V0 as V1
            for(int ag=0; ag<20; ag++){ 
            for(int tb=0; tb<9; tb++){
            for(int sx=0; sx<2; sx++){ 
            for(int ms=0; ms<5; ms++){
            V0[ag][tb][sx][ms] = V1[ag][tb][sx][ms];
            }
            }  
            }
            }
            
            } //// end of month loop! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
            } //// end of year loop! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    return Rcpp::List::create(
      Rcpp::Named("Trace") = Trace,
      Rcpp::Named("Out") = Out
      );}')

