rm(list=ls())
setwd("/Users/nicolasmenzie/Google Drive/Harvard/Shanghai TB modelling/ShanghaiTB_6-22/3-Calibration")


library(RColorBrewer)
cls <-  c("grey40",brewer.pal(9, "Set1")[-6])
mTrsp <- function(cl,a)  { apply(col2rgb(cl), 2, function(x){ rgb(x[1],x[2],x[3],a,maxColorValue=255)}) }
clsp <-  brewer.pal(12, "Paired")

load("scen_sim_11-21-2019.rData") # scen_sim
load("data_inputs_10-10-19.rData")
load("calib_inputs_8-26-19.rData") 
load("prior_objects_10_31_2019.rData") 
source("process_parameters_proj_V3.r")
source("calibration_functions_V1.r")

 dimnames(scen_sim)[[3]]

pdf_suffix <- "Fig_Shanghai_manuscript_11-22-2019"

##################################################
###################  FIGURE 1 ####################  
##################################################

pdfnam <- paste0(pdf_suffix, "_1.pdf")
pdf(file=pdfnam,width=7, height=5.5) 
par(mfcol=c(2,3),mar=c(2.7,3.2,1.4,.3),oma=c(0,0,0.3,0))
### Panel 1 - Population by year and migrant status
res1a <- apply(scen_sim[1:18,,"TotRes",,],c(1,3,4),sum)
res2a <- apply(res1a,c(1,3),mean)[,1]
res3a <- apply(res1a[,,1],1,function(x) quantile(x,c(1,39)/40))
res1b <- apply(scen_sim[1:18,,"TotMig",,],c(1,3,4),sum)
res2b <- apply(res1b,c(1,3),mean)[,1]
res3b <- apply(res1b[,,1],1,function(x) quantile(x,c(1,39)/40))
##
plot(0,0,ylim=1.2*c(0.028,1),xlim=c(2001.2,2017.8),xlab="",ylab="",axes=F)

polygon(c(2001:2018,2018:2001),c(res3a[1,],res3a[2,18:1])/1e6,border=F,col=mTrsp(clsp[10],80))
lines(2001:2018,res2a/1e6,col=clsp[10],lwd=1,lend="butt")
#
polygon(c(2001:2018,2018:2001),c(res3b[1,],res3b[2,18:1])/1e6,border=F,col=mTrsp(clsp[4],80))
lines(2001:2018,res2b/1e6,col=clsp[4],lwd=1,lend="butt")

lines(2001:2018,true_res_size/1e6,col=clsp[10],lty="22")
lines(2001:2018,true_img_size/1e6,col=clsp[4],lty="22")
points(2001:2018,true_res_size/1e6,col=clsp[10],pch=16,cex=.6)
points(2001:2018,true_img_size/1e6,col=clsp[4],pch=16,cex=.6)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Year",1,1.6,cex=0.7);mtext("Population (mil)",2,2.2,cex=0.7); box(col="grey58")
mtext("A.",3,0.2,cex=1.05,adj=-0.23);

legend(2007,.4,c("Residents: model","Residents: data", "Migrants: model","Migrants: data"),
       cex=0.9,lty=c(1,3,1,3),col=clsp[c(10,10,4,4)],pch=c(22,16,22,16),pt.bg=c(mTrsp(clsp[c(10,10,4,4)],100)),
       pt.cex=c(2.3,0.7,2.3,0.7),pt.lwd=0,bty="n")

### Panel 2 - Population by Age and migrant status
res1a <- scen_sim[18,,"TotRes",,1]/1e6
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))
res1b <- scen_sim[18,,"TotMig",,1]/1e6
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
##
plot(0,0,ylim=.2*c(0.028,1),xlim=c(0,100),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))

lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
#

lines(0:19*5+2.5,true_res_age[,3]/1e6,col=clsp[10],lty="22")
lines(0:19*5+2.5,true_mig_age[,3]/1e6,col=clsp[4],lty="22")
points(0:19*5+2.5,true_res_age[,3]/1e6,col=clsp[10],pch=16,cex=.6)
points(0:19*5+2.5,true_mig_age[,3]/1e6,col=clsp[4],pch=16,cex=.6)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("Population (mil)",2,2.2,cex=0.7); box(col="grey58")
mtext("B.",3,0.2,cex=1.05,adj=-0.23);

legend(38,.198,c("Residents: model","Residents: data", "Migrants: model","Migrants: data"),
       cex=0.9,lty=c(1,3,1,3),col=clsp[c(10,10,4,4)],pch=c(22,16,22,16),pt.bg=c(mTrsp(clsp[c(10,10,4,4)],100)),
       pt.cex=c(2.3,0.7,2.3,0.7),pt.lwd=0,bty="n")

### Panel 3 - TB cases by year and migrant status
res1a <- apply(scen_sim[1:18,,c("TotNotifResMale","TotNotifResFemale"),,],c(1,4,5),sum)
res2a <- apply(res1a[,,1],1,mean)
res3a <- apply(res1a[,,1],1,function(x) quantile(x,c(1,39)/40))
res1b <- apply(scen_sim[1:18,,c("TotNotifMigMale","TotNotifMigFemale"),,],c(1,4,5),sum)
res2b <- apply(res1b[,,1],1,mean)
res3b <- apply(res1b[,,1],1,function(x) quantile(x,c(1,39)/40))
##
plot(0,0,ylim=520*c(0.028,1),xlim=c(2001.2,2017.8),xlab="",ylab="",axes=F)

polygon(c(2001:2018,2018:2001),c(res3a[1,],res3a[2,18:1]),border=F,col=mTrsp(clsp[10],80))
lines(2001:2018,res2a,col=clsp[10],lwd=1,lend="butt")
#
polygon(c(2001:2018,2018:2001),c(res3b[1,],res3b[2,18:1]),border=F,col=mTrsp(clsp[4],80))
lines(2001:2018,res2b,col=clsp[4],lwd=1,lend="butt")

lines(2001:2018,true_notification_res,col=clsp[10],lty="22")
lines(2001:2018,true_notification_mig,col=clsp[4],lty="22")
points(2001:2018,true_notification_res,col=clsp[10],pch=16,cex=.6)
points(2001:2018,true_notification_mig,col=clsp[4],pch=16,cex=.6)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Year",1,1.6,cex=0.7);mtext("TB cases",2,2.2,cex=0.7); box(col="grey58")
mtext("C.",3,0.2,cex=1.05,adj=-0.23);

legend(2000.7,540,c("Residents: model","Residents: data", "Migrants: model","Migrants: data"),
       cex=0.9,lty=c(1,3,1,3),col=clsp[c(10,10,4,4)],pch=c(22,16,22,16),pt.bg=c(mTrsp(clsp[c(10,10,4,4)],100)),
       pt.cex=c(2.3,0.7,2.3,0.7),pt.lwd=0,bty="n")

### Panel 4 - TB cases fatality by age
res1a <- apply(scen_sim[1:17,,"Fatality",,],c(2,3,4),sum)/apply(scen_sim[1:17,,c("TotNotifResMale","TotNotifResFemale"),,],c(2,4,5),sum)
res2a <- apply(res1a[,,1],1,mean)
res3a <- apply(res1a[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0,0,ylim=27*c(0.028,1),xlim=c(0,100),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1])*100,border=F,col=mTrsp(clsp[12],80))
lines(0:19*5+2.5,res2a*100,col=clsp[12],lwd=1,lend="butt")

lines(0:19*5+2.5,true_casefata_mu*100,col=clsp[12],lty="22")
points(0:19*5+2.5,true_casefata_mu*100,col=clsp[12],pch=16,cex=.6)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("Case fatality (%)",2,2.2,cex=0.7); box(col="grey58")
mtext("D.",3,0.2,cex=1.05,adj=-0.23);

legend(20,20,c("Model","Data"),
       cex=0.9,lty=c(1,3),col=clsp[12],pch=c(22,16),pt.bg=c(mTrsp(clsp[12],100)),
       pt.cex=c(2.3,0.7),pt.lwd=0,bty="n")

### Panel 5 - TB cases by Age and sex, residents
res1a <- apply(scen_sim[8:18,,"TotNotifResMale",,],c(2,3,4),sum)
res2a <- apply(res1a[,,1],1,mean)
res3a <- apply(res1a[,,1],1,function(x) quantile(x,c(1,39)/40))
res1b <- apply(scen_sim[8:18,,"TotNotifResFemale",,],c(2,3,4),sum)
res2b <- apply(res1b[,,1],1,mean)
res3b <- apply(res1b[,,1],1,function(x) quantile(x,c(1,39)/40))

##
plot(0,0,ylim=175*c(0.028,1),xlim=c(0,100),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[2],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[6],80))

lines(0:19*5+2.5,res2a,col=clsp[2],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[6],lwd=1,lend="butt")
#

lines(0:19*5+2.5,rowSums(true_notif_res_male),col=clsp[2],lty="22")
lines(0:19*5+2.5,rowSums(true_notif_res_female),col=clsp[6],lty="22")
points(0:19*5+2.5,rowSums(true_notif_res_male),col=clsp[2],pch=16,cex=.6)
points(0:19*5+2.5,rowSums(true_notif_res_female),col=clsp[6],pch=16,cex=.6)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("TB cases",2,2.2,cex=0.7); box(col="grey58")
mtext("E.",3,0.2,cex=1.05,adj=-0.23);

legend(-2,181,c("Males: model","Males: data", "Females: model","Females: data"),
       cex=0.9,lty=c(1,3,1,3),col=clsp[c(2,2,6,6)],pch=c(22,16,22,16),pt.bg=c(mTrsp(clsp[c(2,2,6,6)],100)),
       pt.cex=c(2.3,0.7,2.3,0.7),pt.lwd=0,bty="n")

### Panel 6 - TB cases by Age and sex, migrants
res1a <- apply(scen_sim[8:18,,"TotNotifMigMale",,],c(2,3,4),sum)
res2a <- apply(res1a[,,1],1,mean)
res3a <- apply(res1a[,,1],1,function(x) quantile(x,c(1,39)/40))
res1b <- apply(scen_sim[8:18,,"TotNotifMigFemale",,],c(2,3,4),sum)
res2b <- apply(res1b[,,1],1,mean)
res3b <- apply(res1b[,,1],1,function(x) quantile(x,c(1,39)/40))

##
plot(0,0,ylim=790*c(0.028,1),xlim=c(0,100),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[2],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[6],80))

lines(0:19*5+2.5,res2a,col=clsp[2],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[6],lwd=1,lend="butt")
#

lines(0:19*5+2.5,rowSums(true_notif_mig_male),col=clsp[2],lty="22")
lines(0:19*5+2.5,rowSums(true_notif_mig_female),col=clsp[6],lty="22")
points(0:19*5+2.5,rowSums(true_notif_mig_male),col=clsp[2],pch=16,cex=.6)
points(0:19*5+2.5,rowSums(true_notif_mig_female),col=clsp[6],pch=16,cex=.6)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("TB cases",2,2.2,cex=0.7); box(col="grey58")
mtext("F.",3,0.2,cex=1.05,adj=-0.23);

legend(40,700,c("Males: model","Males: data", "Females: model","Females: data"),
       cex=0.9,lty=c(1,3,1,3),col=clsp[c(2,2,6,6)],pch=c(22,16,22,16),pt.bg=c(mTrsp(clsp[c(2,2,6,6)],100)),
       pt.cex=c(2.3,0.7,2.3,0.7),pt.lwd=0,bty="n")

dev.off();system(paste("open", pdfnam))

##################################################
###################  FIGURE 2 ####################  
##################################################

pdfnam <- paste0(pdf_suffix, "_2.pdf")
pdf(file=pdfnam,width=6.5, height=4.5) 
par(mfrow=c(2,3),mar=c(2.7,3.4,1.4,.3),oma=c(0,0,0.3,0.2))
### Panel 1 - Transmission
res1a <- scen_sim[20,,"TotTbFoiRes",,1]
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))

res1b <- scen_sim[20,,"TotTbFoiMig",,1]
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
##
plot(0,0,ylim=1400*c(0.028,1),xlim=c(2,98),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))
lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("Transmission events",2,2.4,cex=0.7); box(col="grey58")
mtext("A.",3,0.2,cex=1.05,adj=-0.23);


### Panel 2 - Infection
res1a <- scen_sim[20,,"TotTbNltRes",,1]
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))

res1b <- scen_sim[20,,"TotTbNltMig",,1]
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
##
plot(0,0,ylim=1030*c(0.028,1),xlim=c(2,98),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))
lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("New Mtb infections",2,2.4,cex=0.7); box(col="grey58")
mtext("B.",3,0.2,cex=1.05,adj=-0.23);

### Panel 3 - Cases
res1a <- apply(scen_sim[20,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,1],c(1,3),sum)
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))

res1b <- apply(scen_sim[20,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1],c(1,3),sum)
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
##
plot(0,0,ylim=105*c(0.028,1),xlim=c(2,98),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))
lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("New TB cases",2,2.4,cex=0.7); box(col="grey58")
mtext("C.",3,0.2,cex=1.05,adj=-0.23);

### Panel 4 - Deaths
res1a <- scen_sim[20,,"TotTbDthRes",,1]
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))

res1b <- scen_sim[20,,"TotTbDthMig",,1]
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
##
plot(0,0,ylim=2.4*c(0.028,1),xlim=c(2,98),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))
lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("TB deaths",2,2.4,cex=0.7); box(col="grey58")
mtext("D.",3,0.2,cex=1.05,adj=-0.23);

### Panel 5 - YLL
res1a <- scen_sim[20,,"TotTbYllRes",,1]
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))

res1b <- scen_sim[20,,"TotTbYllMig",,1]
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
##
plot(0,0,ylim=110*c(0.028,1),xlim=c(2,98),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))
lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("Life-years lost to TB",2,2.4,cex=0.7); box(col="grey58")
mtext("E.",3,0.2,cex=1.05,adj=-0.23);

#
plot.new() # or frame()

legend("center",c("Migrants","Residents"),
       cex=1,lty=1,col=clsp[c(4,10)],pch=22,pt.bg=c(mTrsp(clsp[c(4,10)],100)),
       pt.cex=2.3,pt.lwd=0,box.col="grey58")

dev.off();system(paste("open", pdfnam))

##################################################
###################  FIGURE 2b ####################  
##################################################

pdfnam <- paste0(pdf_suffix, "_2b.pdf")
pdf(file=pdfnam,width=7.5, height=5.25) 
par(mfrow=c(2,3),mar=c(2.7,3.3,1.4,.3),oma=c(0.3,0.4,0.3,0))
### Panel 1 - Transmission
res1a <- scen_sim[20,,"TotTbFoiRes",,1]/scen_sim[20,,"TotRes",,1]*1e5
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))
res1ma <- apply(scen_sim[20,,"TotTbFoiRes",,1],2,sum)/apply(scen_sim[20,,"TotRes",,1],2,sum)*1e5
res2ma <- mean(res1ma)
res3ma <- quantile(res1ma,c(1,39)/40)

res1b <- scen_sim[20,,"TotTbFoiMig",,1]/scen_sim[20,,"TotMig",,1]*1e5
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
res1mb <- apply(scen_sim[20,,"TotTbFoiMig",,1],2,sum)/apply(scen_sim[20,,"TotMig",,1],2,sum)*1e5
res2mb <- mean(res1mb)
res3mb <- quantile(res1mb,c(1,39)/40)

##
plot(0,0,ylim=770*c(0.028,1),xlim=c(2,109),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))
lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
polygon(c(105,109,109,105),rep(res3mb,each=2),border=F,col=mTrsp(clsp[4],80))
polygon(c(105,109,109,105),rep(res3ma,each=2),border=F,col=mTrsp(clsp[10],80))
lines(c(105,109),rep(res2mb,2),col=clsp[4],lwd=1)
lines(c(105,109),rep(res2ma,2),col=clsp[10],lwd=1)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
axis(1,108,"Average",las=2,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.7,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("Transmission events per 100,000",2,2.2,cex=0.7); box(col="grey58")
mtext("A.",3,0.2,cex=1.05,adj=-0.23);

### Panel 2 - Infection
res1a <- scen_sim[20,,"TotTbNltRes",,1]/scen_sim[20,,"TotRes",,1]*1e5
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))
res1ma <- apply(scen_sim[20,,"TotTbNltRes",,1],2,sum)/apply(scen_sim[20,,"TotRes",,1],2,sum)*1e5
res2ma <- mean(res1ma)
res3ma <- quantile(res1ma,c(1,39)/40)

res1b <- scen_sim[20,,"TotTbNltMig",,1]/scen_sim[20,,"TotMig",,1]*1e5
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
res1mb <- apply(scen_sim[20,,"TotTbNltMig",,1],2,sum)/apply(scen_sim[20,,"TotMig",,1],2,sum)*1e5
res2mb <- mean(res1mb)
res3mb <- quantile(res1mb,c(1,39)/40)

##
plot(0,0,ylim=550*c(0.028,1),xlim=c(2,109),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))
lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
polygon(c(105,109,109,105),rep(res3mb,each=2),border=F,col=mTrsp(clsp[4],80))
polygon(c(105,109,109,105),rep(res3ma,each=2),border=F,col=mTrsp(clsp[10],80))
lines(c(105,109),rep(res2mb,2),col=clsp[4],lwd=1)
lines(c(105,109),rep(res2ma,2),col=clsp[10],lwd=1)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
axis(1,108,"Average",las=2,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.7,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("New Mtb infections per 100,000",2,2.2,cex=0.7); box(col="grey58")
mtext("B.",3,0.2,cex=1.05,adj=-0.23);

### Panel 3 - Cases
res1a <- apply(scen_sim[20,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,1],c(1,3),sum)/scen_sim[20,,"TotRes",,1]*1e5
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))
res1ma <- apply(scen_sim[20,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,1],3,sum)/apply(scen_sim[20,,"TotRes",,1],2,sum)*1e5
res2ma <- mean(res1ma)
res3ma <- quantile(res1ma,c(1,39)/40)

res1b <- apply(scen_sim[20,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1],c(1,3),sum)/scen_sim[20,,"TotMig",,1]*1e5
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
res1mb <- apply(scen_sim[20,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1],3,sum)/apply(scen_sim[20,,"TotMig",,1],2,sum)*1e5
res2mb <- mean(res1mb)
res3mb <- quantile(res1mb,c(1,39)/40)

##
plot(0,0,ylim=205*c(0.028,1),xlim=c(2,109),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))
lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
polygon(c(105,109,109,105),rep(res3mb,each=2),border=F,col=mTrsp(clsp[4],80))
polygon(c(105,109,109,105),rep(res3ma,each=2),border=F,col=mTrsp(clsp[10],80))
lines(c(105,109),rep(res2mb,2),col=clsp[4],lwd=1)
lines(c(105,109),rep(res2ma,2),col=clsp[10],lwd=1)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
axis(1,108,"Average",las=2,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.7,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("New TB cases per 100,000",2,2.2,cex=0.7); box(col="grey58")
mtext("C.",3,0.2,cex=1.05,adj=-0.23);

### Panel 4 - Deaths
res1a <- scen_sim[20,,"TotTbDthRes",,1]/scen_sim[20,,"TotRes",,1]*1e5
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))
res1ma <- apply(scen_sim[20,,"TotTbDthRes",,1],2,sum)/apply(scen_sim[20,,"TotRes",,1],2,sum)*1e5
res2ma <- mean(res1ma)
res3ma <- quantile(res1ma,c(1,39)/40)

res1b <- scen_sim[20,,"TotTbDthMig",,1]/scen_sim[20,,"TotMig",,1]*1e5
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
res1mb <- apply(scen_sim[20,,"TotTbDthMig",,1],2,sum)/apply(scen_sim[20,,"TotMig",,1],2,sum)*1e5
res2mb <- mean(res1mb)
res3mb <- quantile(res1mb,c(1,39)/40)

##
plot(0,0,ylim=34*c(0.028,1),xlim=c(2,109),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))
lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
polygon(c(105,109,109,105),rep(res3mb,each=2),border=F,col=mTrsp(clsp[4],80))
polygon(c(105,109,109,105),rep(res3ma,each=2),border=F,col=mTrsp(clsp[10],80))
lines(c(105,109),rep(res2mb,2),col=clsp[4],lwd=1)
lines(c(105,109),rep(res2ma,2),col=clsp[10],lwd=1)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
axis(1,108,"Average",las=2,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.7,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("TB deaths per 100,000",2,2.2,cex=0.7); box(col="grey58")
mtext("D.",3,0.2,cex=1.05,adj=-0.23);

### Panel 5 - YLL
res1a <- scen_sim[20,,"TotTbYllRes",,1]/scen_sim[20,,"TotRes",,1]*1e5
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a,1,function(x) quantile(x,c(1,39)/40))
res1ma <- apply(scen_sim[20,,"TotTbYllRes",,1],2,sum)/apply(scen_sim[20,,"TotRes",,1],2,sum)*1e5
res2ma <- mean(res1ma)
res3ma <- quantile(res1ma,c(1,39)/40)

res1b <- scen_sim[20,,"TotTbYllMig",,1]/scen_sim[20,,"TotMig",,1]*1e5
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b,1,function(x) quantile(x,c(1,39)/40))
res1mb <- apply(scen_sim[20,,"TotTbYllMig",,1],2,sum)/apply(scen_sim[20,,"TotMig",,1],2,sum)*1e5
res2mb <- mean(res1mb)
res3mb <- quantile(res1mb,c(1,39)/40)

##
plot(0,0,ylim=70*c(0.028,1),xlim=c(2,109),xlab="",ylab="",axes=F,col="white")
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1]),border=F,col=mTrsp(clsp[10],80))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1]),border=F,col=mTrsp(clsp[4],80))
lines(0:19*5+2.5,res2a,col=clsp[10],lwd=1,lend="butt")
lines(0:19*5+2.5,res2b,col=clsp[4],lwd=1,lend="butt")
polygon(c(105,109,109,105),rep(res3mb,each=2),border=F,col=mTrsp(clsp[4],80))
polygon(c(105,109,109,105),rep(res3ma,each=2),border=F,col=mTrsp(clsp[10],80))
lines(c(105,109),rep(res2mb,2),col=clsp[4],lwd=1)
lines(c(105,109),rep(res2ma,2),col=clsp[10],lwd=1)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
axis(1,108,"Average",las=2,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.7,col="grey58")
mtext("Age",1,1.6,cex=0.7);mtext("Life-years lost to TB per 100,000",2,2.2,cex=0.7); box(col="grey58")
mtext("E.",3,0.2,cex=1.05,adj=-0.23);

#
plot.new() # or frame()

legend("center",c("Migrants","Residents"),
       cex=1,lty=1,col=clsp[c(4,10)],pch=22,pt.bg=c(mTrsp(clsp[c(4,10)],100)),
       pt.cex=2.3,pt.lwd=0,box.col="grey58")

dev.off();system(paste("open", pdfnam))

##################################################
###################  FIGURE 3 ####################  
##################################################

pdfnam <- paste0(pdf_suffix, "_3.pdf")
pdf(file=pdfnam,width=7.5, height=5.25) 
par(mfrow=c(1,2),mar=c(3.0,2.8,1.7,.5),oma=c(2,0,0,0))

res1a <- apply(scen_sim[20,,"ImpCaseRes",,],c(1,2,3),sum)/apply(scen_sim[20,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,],c(1,3,4),sum)
res1b <- apply(scen_sim[20,,c("RtIncidRes","ImpCaseRes"),,],c(1,3,4),sum)/apply(scen_sim[20,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,],c(1,3,4),sum)
res2a <- apply(res1a,c(1,3),mean)
res2b <- apply(res1b,c(1,3),mean)
res3a <- apply(res1a[,,1],1,function(x) quantile(x,c(1,39)/40))
res3b <- apply(res1b[,,1],1,function(x) quantile(x,c(1,39)/40))

####
res1ma <- apply(scen_sim[20,,"ImpCaseRes",,],c(2,3),sum)/apply(scen_sim[20,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,],c(3,4),sum)
res1mb <- apply(scen_sim[20,,c("RtIncidRes","ImpCaseRes"),,],c(3,4),sum)/apply(scen_sim[20,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,],c(3,4),sum)
res2ma <- apply(res1ma,2,mean)
res2mb <- apply(res1mb,2,mean)
res3ma <- quantile(res1ma[,1],c(1,39)/40)
res3mb <- quantile(res1mb[,1],c(1,39)/40)
#
plot(0:19*5+2.5,0:19+1,ylim=c(3,97),xlim=c(3,115),col="white",xlab="",ylab="",axes=F)

polygon(c(0:19,19:0)*5+2.5,c(rep(1,20),rep(0,20))*1e2,border=mTrsp(1,80),col=cls[4])
polygon(c(0:19,19:0)*5+2.5,c(res2b[,1],rep(0,20))*1e2,border=mTrsp(1,80),col=cls[6])
polygon(c(0:19,19:0)*5+2.5,c(res2a[,1],rep(0,20))*1e2,border=mTrsp(1,80),col=cls[3])
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1])*1e2,border=mTrsp(1,35),lty=1,col=mTrsp(1,25))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1])*1e2,border=mTrsp(1,35),lty=1,col=mTrsp(1,25))
##
polygon(c(0,10,10,0)+107,c(1,1,0,0)*1e2,border=mTrsp(1,80),col=cls[4])
polygon(c(0,10,10,0)+107,c(res2mb[1],res2mb[1],0,0)*1e2,border=mTrsp(1,80),col=cls[6])
polygon(c(0,10,10,0)+107,c(res2ma[1],res2ma[1],0,0)*1e2,border=mTrsp(1,80),col=cls[3])
polygon(c(0,10,10,0)+107,rep(res3ma,each=2)*1e2,border=mTrsp(1,35),lty=1,col=mTrsp(1,25))
polygon(c(0,10,10,0)+107,rep(res3mb,each=2)*1e2,border=mTrsp(1,35),lty=1,col=mTrsp(1,25))

mtext("A.",3,0.5,cex=1.1,adj=-0.17);

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
axis(1,111,"Average",las=2,tcl=-.2,mgp=c(3, 0.4, 0),cex.axis=0.75,col="grey58")

mtext("Age",1,1.4);mtext("Percent of resident TB cases",2,1.8); box()
#
res1a <- apply(scen_sim[20,,"ImpCaseMig",,],c(1,2,3),sum)/apply(scen_sim[20,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,],c(1,3,4),sum)
res1b <- apply(scen_sim[20,,c("RtIncidMig","ImpCaseMig"),,],c(1,3,4),sum)/apply(scen_sim[20,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,],c(1,3,4),sum)
res2a <- apply(res1a,c(1,3),mean)
res2b <- apply(res1b,c(1,3),mean)
res3a <- apply(res1a[,,1],1,function(x) quantile(x,c(1,39)/40))
res3b <- apply(res1b[,,1],1,function(x) quantile(x,c(1,39)/40))
#
res1ma <- apply(scen_sim[20,,"ImpCaseMig",,],c(2,3),sum)/apply(scen_sim[20,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,],c(3,4),sum)
res1mb <- apply(scen_sim[20,,c("RtIncidMig","ImpCaseMig"),,],c(3,4),sum)/apply(scen_sim[20,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,],c(3,4),sum)
res2ma <- apply(res1ma,2,mean)
res2mb <- apply(res1mb,2,mean)
res3ma <- quantile(res1ma[,1],c(1,39)/40)
res3mb <- quantile(res1mb[,1],c(1,39)/40)

plot(0:19*5+2.5,0:19+1,ylim=c(3,97),xlim=c(3,115),col="white",xlab="",ylab="",axes=F)

polygon(c(0:19,19:0)*5+2.5,c(rep(1,20),rep(0,20))*1e2,border=mTrsp(1,80),col=cls[4])
polygon(c(0:19,19:0)*5+2.5,c(res2b[,1],rep(0,20))*1e2,border=mTrsp(1,80),col=cls[6])
polygon(c(0:19,19:0)*5+2.5,c(res2a[,1],rep(0,20))*1e2,border=mTrsp(1,80),col=cls[3])
polygon(c(0:19,19:0)*5+2.5,c(res3a[1,],res3a[2,20:1])*1e2,border=mTrsp(1,35),lty=1,col=mTrsp(1,25))
polygon(c(0:19,19:0)*5+2.5,c(res3b[1,],res3b[2,20:1])*1e2,border=mTrsp(1,35),lty=1,col=mTrsp(1,25))
##
polygon(c(0,10,10,0)+107,c(1,1,0,0)*1e2,border=mTrsp(1,80),col=cls[4])
polygon(c(0,10,10,0)+107,c(res2mb[1],res2mb[1],0,0)*1e2,border=mTrsp(1,80),col=cls[6])
polygon(c(0,10,10,0)+107,c(res2ma[1],res2ma[1],0,0)*1e2,border=mTrsp(1,80),col=cls[3])
polygon(c(0,10,10,0)+107,rep(res3ma,each=2)*1e2,border=mTrsp(1,35),lty=1,col=mTrsp(1,25))
polygon(c(0,10,10,0)+107,rep(res3mb,each=2)*1e2,border=mTrsp(1,35),lty=1,col=mTrsp(1,25))

mtext("B.",3,0.5,cex=1.1,adj=-0.17);

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
axis(1,111,"Average",las=2,tcl=-.2,mgp=c(3, 0.4, 0),cex.axis=0.75,col="grey58")
mtext("Age",1,1.4);mtext("Percent of migrant TB cases",2,1.8); box()

legend(-110,-17,c("LTBI reactivation","Recent Mtb infection","Prevalent TB at entry"),
       col=cls[c(4,6,3)],pch=15,pt.cex=1.7,cex=0.8,xpd=NA,ncol=3)
#
dev.off();system(paste("open", pdfnam))

##################################################
###################  FIGURE 4 ####################  
##################################################

pdfnam <- paste0(pdf_suffix, "_4.pdf")
pdf(file=pdfnam,width=8, height=4.5) 
par(mfrow=c(1,3),mar=c(3.0,3.3,1.7,.5),oma=c(0,0.2,0,0))

## Population
res1a <- apply(scen_sim[10:35,,"TotRes",,],c(1,3,4),sum)/1e6
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a[,,1],1,function(x) quantile(x,c(1,39)/40))

res1b <- apply(scen_sim[10:35,,"TotMig",,],c(1,3,4),sum)/1e6
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b[,,1],1,function(x) quantile(x,c(1,39)/40))

res1c <- apply(scen_sim[10:35,,c("TotRes","TotMig"),,],c(1,4,5),sum)/1e6
res2c <- apply(res1c,1,mean)
res3c <- apply(res1c[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0,0,ylim=2.440*c(0.028,1),xlim=c(2010.2,2034.8),xlab="",ylab="",axes=F)
#
polygon(c(2010:2035,2035:2010),c(res3c[1,],res3c[2,26:1]),border=F,col=mTrsp(cls[1],70))
lines(2010:2018,res2c[1:9],col=cls[1],lwd=1,lend="butt")
lines(2018:2035,res2c[-(1:8)],col=cls[1],lwd=1,lend="butt",lty="22")
polygon(c(2010:2035,2035:2010),c(res3a[1,],res3a[2,26:1]),border=F,col=mTrsp(clsp[10],70))
lines(2010:2018,res2a[1:9],col=clsp[10],lwd=1,lend="butt")
lines(2018:2035,res2a[-(1:8)],col=clsp[10],lwd=1,lend="butt",lty="22")
polygon(c(2010:2035,2035:2010),c(res3b[1,],res3b[2,26:1]),border=F,col=mTrsp(clsp[4],70))
lines(2010:2018,res2b[1:9],col=clsp[4],lwd=1,lend="butt")
lines(2018:2035,res2b[-(1:8)],col=clsp[4],lwd=1,lend="butt",lty="22")

points(2010:2018,true_res_size[10:18]/1e6,col=clsp[10],pch=16,cex=.6)
points(2010:2018,true_img_size[10:18]/1e6,col=clsp[4],pch=16,cex=.6)
points(2010:2018,(true_img_size+true_res_size)[10:18]/1e6,col=cls[1],pch=16,cex=.6)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Year",1,1.6,cex=0.7);mtext("Population (000s)",2,2.4,cex=0.7); box(col="grey58")
mtext("A.",3,0.2,cex=1.05,adj=-0.23);

legend(2022,0.55,c("Residents: model","Residents: data", "Migrants: model","Migrants: data",
                  "Total pop: model","Total pop: data"),cex=0.9,lty=c(1,NA,1,NA,1,NA),
       col=c(clsp[c(10,10,4,4)],cls[c(1,1)]),pch=c(22,16,22,16,22,16),
       pt.bg=c(mTrsp(c(clsp[c(10,10,4,4)],cls[c(1,1)]),90)),
       pt.cex=c(2.3,0.6,2.3,0.6,2.3,0.6),pt.lwd=0,bty="n")

## Cases

res1a <- apply(scen_sim[10:35,,c("TotNotifResMale","TotNotifResFemale"),,],c(1,4,5),sum)
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a[,,1],1,function(x) quantile(x,c(1,39)/40))

res1b <- apply(scen_sim[10:35,,c("TotNotifMigMale","TotNotifMigFemale"),,],c(1,4,5),sum)
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b[,,1],1,function(x) quantile(x,c(1,39)/40))

res1c <- apply(scen_sim[10:35,,c("TotNotifMigMale","TotNotifMigFemale","TotNotifResMale","TotNotifResFemale"),,],c(1,4,5),sum)
res2c <- apply(res1c,1,mean)
res3c <- apply(res1c[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0,0,ylim=700*c(0.028,1),xlim=c(2010.2,2034.8),xlab="",ylab="",axes=F)
#
polygon(c(2010:2035,2035:2010),c(res3c[1,],res3c[2,26:1]),border=F,col=mTrsp(cls[1],70))
lines(2010:2018,res2c[1:9],col=cls[1],lwd=1,lend="butt")
lines(2018:2035,res2c[-(1:8)],col=cls[1],lwd=1,lend="butt",lty="22")
polygon(c(2010:2035,2035:2010),c(res3a[1,],res3a[2,26:1]),border=F,col=mTrsp(clsp[10],70))
lines(2010:2018,res2a[1:9],col=clsp[10],lwd=1,lend="butt")
lines(2018:2035,res2a[-(1:8)],col=clsp[10],lwd=1,lend="butt",lty="22")
polygon(c(2010:2035,2035:2010),c(res3b[1,],res3b[2,26:1]),border=F,col=mTrsp(clsp[4],70))
lines(2010:2018,res2b[1:9],col=clsp[4],lwd=1,lend="butt")
lines(2018:2035,res2b[-(1:8)],col=clsp[4],lwd=1,lend="butt",lty="22")

points(2010:2018,true_notification_res[10:18],col=clsp[10],pch=16,cex=.6)
points(2010:2018,true_notification_mig[10:18],col=clsp[4],pch=16,cex=.6)
points(2010:2018,(true_notification_mig+true_notification_res)[10:18],col=cls[1],pch=16,cex=.6)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Year",1,1.6,cex=0.7);mtext("New TB cases",2,2.4,cex=0.7); box(col="grey58")
mtext("B.",3,0.2,cex=1.05,adj=-0.23);

legend(2022,720,c("Residents: model","Residents: data", "Migrants: model","Migrants: data",
                  "Total pop: model","Total pop: data"),cex=0.9,lty=c(1,NA,1,NA,1,NA),
       col=c(clsp[c(10,10,4,4)],cls[c(1,1)]),pch=c(22,16,22,16,22,16),
       pt.bg=c(mTrsp(c(clsp[c(10,10,4,4)],cls[c(1,1)]),90)),
       pt.cex=c(2.3,0.6,2.3,0.6,2.3,0.6),pt.lwd=0,bty="n")

## Inc rate

res1a <- apply(scen_sim[10:35,,c("TotNotifResMale","TotNotifResFemale"),,],c(1,4,5),sum)/apply(scen_sim[10:35,,"TotRes",,],c(1,3,4),sum)*1e5
res2a <- apply(res1a,1,mean)
res3a <- apply(res1a[,,1],1,function(x) quantile(x,c(1,39)/40))

res1b <- apply(scen_sim[10:35,,c("TotNotifMigMale","TotNotifMigFemale"),,],c(1,4,5),sum)/apply(scen_sim[10:35,,"TotMig",,],c(1,3,4),sum)*1e5
res2b <- apply(res1b,1,mean)
res3b <- apply(res1b[,,1],1,function(x) quantile(x,c(1,39)/40))

res1c <- apply(scen_sim[10:35,,c("TotNotifMigMale","TotNotifMigFemale","TotNotifResMale","TotNotifResFemale"),,],c(1,4,5),sum)/
  apply(scen_sim[10:35,,c("TotRes","TotMig"),,],c(1,4,5),sum)*1e5
res2c <- apply(res1c,1,mean)
res3c <- apply(res1c[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0,0,ylim=49*c(0.028,1),xlim=c(2010.2,2034.8),xlab="",ylab="",axes=F)
#
polygon(c(2010:2035,2035:2010),c(res3c[1,],res3c[2,26:1]),border=F,col=mTrsp(cls[1],70))
lines(2010:2018,res2c[1:9],col=cls[1],lwd=1,lend="butt")
lines(2018:2035,res2c[-(1:8)],col=cls[1],lwd=1,lend="butt",lty="22")

polygon(c(2010:2035,2035:2010),c(res3a[1,],res3a[2,26:1]),border=F,col=mTrsp(clsp[10],70))
lines(2010:2018,res2a[1:9],col=clsp[10],lwd=1,lend="butt")
lines(2018:2035,res2a[-(1:8)],col=clsp[10],lwd=1,lend="butt",lty="22")
#
polygon(c(2010:2035,2035:2010),c(res3b[1,],res3b[2,26:1]),border=F,col=mTrsp(clsp[4],70))
lines(2010:2018,res2b[1:9],col=clsp[4],lwd=1,lend="butt")
lines(2018:2035,res2b[-(1:8)],col=clsp[4],lwd=1,lend="butt",lty="22")

points(2010:2018,(true_notification_res/true_res_size)[10:18]*1e5,col=clsp[10],pch=16,cex=.6)
points(2010:2018,(true_notification_mig/true_img_size)[10:18]*1e5,col=clsp[4],pch=16,cex=.6)
points(2010:2018,((true_notification_res+true_notification_mig)/(true_img_size+true_res_size))[10:18]*1e5,col=cls[1],pch=16,cex=.6)

axis(2,las=1,tcl=-.2,mgp=c(3, 0.5, 0),cex.axis=0.9,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Year",1,1.6,cex=0.7);mtext("TB cases per 100,000",2,2.4,cex=0.7); box(col="grey58")
mtext("C.",3,0.2,cex=1.05,adj=-0.23);

legend(2022,51,c("Residents: model","Residents: data", "Migrants: model","Migrants: data",
                  "Total pop: model","Total pop: data"),cex=0.9,lty=c(1,NA,1,NA,1,NA),
       col=c(clsp[c(10,10,4,4)],cls[c(1,1)]),pch=c(22,16,22,16,22,16),
       pt.bg=c(mTrsp(c(clsp[c(10,10,4,4)],cls[c(1,1)]),90)),
       pt.cex=c(2.3,0.6,2.3,0.6,2.3,0.6),pt.lwd=0,bty="n")

dev.off();system(paste("open", pdfnam))

##################


##################################################
###################  FIGURE 5 ####################  
##################################################

pdfnam <- paste0(pdf_suffix, "_5.pdf")
pdf(file=pdfnam,width=10, height=5) 
par(mfcol=c(2,5),mar=c(2.5,3.5,1.1,.5),oma=c(0,0.1,.5,.2))

# Incremental resident effective TB contacts by age,\n2020-2035, vs base-case
res1 <- apply(scen_sim[20:35,,"TotTbFoiRes",,],c(2,3,4),sum)
res2 <- apply(res1,c(1,3),mean)
res3 <- apply(res1[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0:19*5+2.5,0:19,ylim=c(-1850,0.0),col="white",xlab="",ylab="",axes=F)
for(i in 6:1){  lines(0:19*5+2.5,res2[,i]-res2[,1],col=cls[i]) } 
legend("bottomright",bty="n",c("Base case",paste0("Scenario ",1:5)),
       col=cls[1:6],lty=1,pch=NA,pt.cex=0.6,cex=0.85,seg.len=1.2,lwd=2)
axis(2,las=1,tcl=-.15,mgp=c(3, 0.3, 0),cex.axis=0.85,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.3,cex=0.7);mtext("Transmission events by residents",2,2.5,cex=0.7); box(col="grey58")
mtext("A.",3,0.3,cex=.9,adj=-0.29);

#Incremental migrant effective TB contacts by age,\n2020-2035, vs base-case
res1 <- apply(scen_sim[20:35,,"TotTbFoiMig",,],c(2,3,4),sum)
res2 <- apply(res1,c(1,3),mean)
res3 <- apply(res1[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0:19*5+2.5,0:19,ylim=c(-1850,0.0),col="white",xlab="",ylab="",axes=F)
for(i in 6:1){  lines(0:19*5+2.5,res2[,i]-res2[,1],col=cls[i]) } 
legend("bottomright",bty="n",c("Base case",paste0("Scenario ",1:5)),
       col=cls[1:6],lty=1,pch=NA,pt.cex=0.6,cex=0.85,seg.len=1.2,lwd=2)
axis(2,las=1,tcl=-.15,mgp=c(3, 0.3, 0),cex.axis=0.85,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.3,cex=0.7);mtext("Transmission events by migrants",2,2.5,cex=0.7); box(col="grey58")
mtext("B.",3,0.3,cex=.9,adj=-0.29);

###########
# Incremental resident new infections by age,\n2020-2035, vs base-case
res1 <- apply(scen_sim[20:35,,"TotTbNltRes",,],c(2,3,4),sum)
res2 <- apply(res1,c(1,3),mean)
res3 <- apply(res1[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0:19*5+2.5,0:19,ylim=c(-1400,0.0),col="white",xlab="",ylab="",axes=F)
for(i in 6:1){  lines(0:19*5+2.5,res2[,i]-res2[,1],col=cls[i]) } 
legend("bottomright",bty="n",c("Base case",paste0("Scenario ",1:5)),
       col=cls[1:6],lty=1,pch=NA,pt.cex=0.6,cex=0.85,seg.len=1.2,lwd=2)
axis(2,las=1,tcl=-.15,mgp=c(3, 0.3, 0),cex.axis=0.85,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.3,cex=0.7);mtext("New Mtb infections in residents",2,2.5,cex=0.7); box(col="grey58")
mtext("C.",3,0.3,cex=.9,adj=-0.29);

#Incremental migrant new infections contacts by age,\n2020-2035, vs base-case
res1 <- apply(scen_sim[20:35,,"TotTbNltMig",,],c(2,3,4),sum)
res2 <- apply(res1,c(1,3),mean)
res3 <- apply(res1[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0:19*5+2.5,0:19,ylim=c(-1400,0.0),col="white",xlab="",ylab="",axes=F)
for(i in 6:1){  lines(0:19*5+2.5,res2[,i]-res2[,1],col=cls[i]) } 
legend("bottomright",bty="n",c("Base case",paste0("Scenario ",1:5)),
       col=cls[1:6],lty=1,pch=NA,pt.cex=0.6,cex=0.85,seg.len=1.2,lwd=2)
axis(2,las=1,tcl=-.15,mgp=c(3, 0.3, 0),cex.axis=0.85,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.3,cex=0.7);mtext("New Mtb infections in migrants",2,2.5,cex=0.7); box(col="grey58")
mtext("D.",3,0.3,cex=.9,adj=-0.29);

###########
# Incremental resident TB cases by age,\n2020-2035, vs base-case
res1 <- apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,],c(2,4,5),sum)
res2 <- apply(res1,c(1,3),mean)
res3 <- apply(res1[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0:19*5+2.5,0:19,ylim=c(-80,0.0),col="white",xlab="",ylab="",axes=F)
for(i in 6:1){  lines(0:19*5+2.5,res2[,i]-res2[,1],col=cls[i]) } 
legend("bottomright",bty="n",c("Base case",paste0("Scenario ",1:5)),
       col=cls[1:6],lty=1,pch=NA,pt.cex=0.6,cex=0.85,seg.len=1.2,lwd=2)
axis(2,las=1,tcl=-.15,mgp=c(3, 0.3, 0),cex.axis=0.85,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.3,cex=0.7);mtext("New TB cases in residents",2,2.5,cex=0.7); box(col="grey58")
mtext("E.",3,0.3,cex=.9,adj=-0.29);

#Incremental migrant TB cases by age,\n2020-2035, vs base-case
res1 <- apply(scen_sim[20:35,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,],c(2,4,5),sum)
res2 <- apply(res1,c(1,3),mean)
res3 <- apply(res1[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0:19*5+2.5,0:19,ylim=c(-80,0.0),col="white",xlab="",ylab="",axes=F)
for(i in 6:1){  lines(0:19*5+2.5,res2[,i]-res2[,1],col=cls[i]) } 
legend("bottomright",bty="n",c("Base case",paste0("Scenario ",1:5)),
       col=cls[1:6],lty=1,pch=NA,pt.cex=0.6,cex=0.85,seg.len=1.2,lwd=2)
axis(2,las=1,tcl=-.15,mgp=c(3, 0.3, 0),cex.axis=0.85,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.3,cex=0.7);mtext("New TB cases in migrants",2,2.5,cex=0.7); box(col="grey58")
mtext("F.",3,0.3,cex=.9,adj=-0.29);
###########
# Incremental resident TB deaths by age,\n2020-2035, vs base-case
res1 <- apply(scen_sim[20:35,,"TotTbDthRes",,],c(2,3,4),sum)
res2 <- apply(res1,c(1,3),mean)
res3 <- apply(res1[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0:19*5+2.5,0:19,ylim=c(-1.93,0.0),col="white",xlab="",ylab="",axes=F)
for(i in 6:1){  lines(0:19*5+2.5,res2[,i]-res2[,1],col=cls[i]) } 
legend("bottomleft",bty="n",c("Base case",paste0("Scenario ",1:5)),
       col=cls[1:6],lty=1,pch=NA,pt.cex=0.6,cex=0.85,seg.len=1.2,lwd=2)
axis(2,las=1,tcl=-.15,mgp=c(3, 0.3, 0),cex.axis=0.85,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.3,cex=0.7);mtext("TB deaths in residents",2,2.5,cex=0.7); box(col="grey58")
mtext("G.",3,0.3,cex=.9,adj=-0.29);

#Incremental migrant TB deaths contacts by age,\n2020-2035, vs base-case
res1 <- apply(scen_sim[20:35,,"TotTbDthMig",,],c(2,3,4),sum)
res2 <- apply(res1,c(1,3),mean)
res3 <- apply(res1[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0:19*5+2.5,0:19,ylim=c(-1.93,0.0),col="white",xlab="",ylab="",axes=F)
for(i in 6:1){  lines(0:19*5+2.5,res2[,i]-res2[,1],col=cls[i]) } 
legend("bottomright",bty="n",c("Base case",paste0("Scenario ",1:5)),
       col=cls[1:6],lty=1,pch=NA,pt.cex=0.6,cex=0.85,seg.len=1.2,lwd=2)
axis(2,las=1,tcl=-.15,mgp=c(3, 0.3, 0),cex.axis=0.85,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.3,cex=0.7);mtext("TB deaths in migrants",2,2.5,cex=0.7); box(col="grey58")
mtext("H.",3,0.3,cex=.9,adj=-0.29);
###########
# Incremental resident TB deaths by age,\n2020-2035, vs base-case
res1 <- apply(scen_sim[20:35,,"TotTbYllRes",,],c(2,3,4),sum)
res2 <- apply(res1,c(1,3),mean)
res3 <- apply(res1[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0:19*5+2.5,0:19,ylim=c(-92,0.0),col="white",xlab="",ylab="",axes=F)
for(i in 6:1){  lines(0:19*5+2.5,res2[,i]-res2[,1],col=cls[i]) } 
legend("bottomleft",bty="n",c("Base case",paste0("Scenario ",1:5)),
       col=cls[1:6],lty=1,pch=NA,pt.cex=0.6,cex=0.85,seg.len=1.2,lwd=2)
axis(2,las=1,tcl=-.15,mgp=c(3, 0.3, 0),cex.axis=0.85,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.3,cex=0.7);mtext("Life-years lost to TB in residents",2,2.5,cex=0.7); box(col="grey58")
mtext("I.",3,0.3,cex=.9,adj=-0.29);

#Incremental migrant TB deaths contacts by age,\n2020-2035, vs base-case
res1 <- apply(scen_sim[20:35,,"TotTbYllMig",,],c(2,3,4),sum)
res2 <- apply(res1,c(1,3),mean)
res3 <- apply(res1[,,1],1,function(x) quantile(x,c(1,39)/40))

plot(0:19*5+2.5,0:19,ylim=c(-92,0.0),col="white",xlab="",ylab="",axes=F)
for(i in 6:1){  lines(0:19*5+2.5,res2[,i]-res2[,1],col=cls[i]) } 
legend("bottomright",bty="n",c("Base case",paste0("Scenario ",1:5)),
       col=cls[1:6],lty=1,pch=NA,pt.cex=0.6,cex=0.85,seg.len=1.2,lwd=2)
axis(2,las=1,tcl=-.15,mgp=c(3, 0.3, 0),cex.axis=0.85,col="grey58")
axis(1,las=1,tcl=-.2,mgp=c(3, 0.3, 0),cex.axis=0.9,col="grey58")
mtext("Age",1,1.3,cex=0.7);mtext("Life-years lost to TB in migrants",2,2.5,cex=0.7); box(col="grey58")
mtext("J.",3,0.3,cex=.9,adj=-0.29);


dev.off();system(paste("open", pdfnam))

##########################################
 
## SOME TABLES
# rates outcomes
rownm <- paste0(rep(c("scenario1_2020",paste0("scenario",1:7,"_2035")),3),rep(c("_resident","_migrant","_all"),each=8))
colnm <- paste0(rep(c("Transm_events_per100K","Mtb_infections_per100K","New_TB_cases_per100K","TB_deaths_per100K","YLL_to_TB_per100K"),each=3),rep(c("_mn","_lo","_hi"),5))
tab1 <- as.data.frame(matrix(NA,length(rownm),length(colnm)+1))
colnames(tab1) <- c("indicator",colnm)
tab1$indicator <- rownm

#####
mulohi <- function(x) as.numeric(c(mean(x),quantile(x,c(1,39)/40)))

# transmission
tab1[1,2:4] <- mulohi(apply(scen_sim[20,,"TotTbFoiRes",,1],2,sum)/apply(scen_sim[20,,"TotRes",,1],2,sum)*1e5)
for(i in 1:7) tab1[1+i,2:4] <- mulohi(apply(scen_sim[35,,"TotTbFoiRes",,i],2,sum)/apply(scen_sim[35,,"TotRes",,i],2,sum)*1e5)
tab1[9,2:4] <- mulohi(apply(scen_sim[20,,"TotTbFoiMig",,1],2,sum)/apply(scen_sim[20,,"TotMig",,1],2,sum)*1e5)
for(i in 1:7) tab1[9+i,2:4] <- mulohi(apply(scen_sim[35,,"TotTbFoiMig",,i],2,sum)/apply(scen_sim[35,,"TotMig",,i],2,sum)*1e5)
tab1[17,2:4] <- mulohi(apply(scen_sim[20,,c("TotTbFoiRes","TotTbFoiMig"),,1],3,sum)/apply(scen_sim[20,,c("TotRes","TotMig"),,1],3,sum)*1e5)
for(i in 1:7) tab1[17+i,2:4] <- mulohi(apply(scen_sim[35,,c("TotTbFoiRes","TotTbFoiMig"),,i],3,sum)/apply(scen_sim[35,,c("TotRes","TotMig"),,i],3,sum)*1e5)
# infection
tab1[1,2:4+3] <- mulohi(apply(scen_sim[20,,"TotTbNltRes",,1],2,sum)/apply(scen_sim[20,,"TotRes",,1],2,sum)*1e5)
for(i in 1:7) tab1[1+i,2:4+3] <- mulohi(apply(scen_sim[35,,"TotTbNltRes",,i],2,sum)/apply(scen_sim[35,,"TotRes",,i],2,sum)*1e5)
tab1[9,2:4+3] <- mulohi(apply(scen_sim[20,,"TotTbNltMig",,1],2,sum)/apply(scen_sim[20,,"TotMig",,1],2,sum)*1e5)
for(i in 1:7) tab1[9+i,2:4+3] <- mulohi(apply(scen_sim[35,,"TotTbNltMig",,i],2,sum)/apply(scen_sim[35,,"TotMig",,i],2,sum)*1e5)
tab1[17,2:4+3] <- mulohi(apply(scen_sim[20,,c("TotTbNltRes","TotTbNltMig"),,1],3,sum)/apply(scen_sim[20,,c("TotRes","TotMig"),,1],3,sum)*1e5)
for(i in 1:7) tab1[17+i,2:4+3] <- mulohi(apply(scen_sim[35,,c("TotTbNltRes","TotTbNltMig"),,i],3,sum)/apply(scen_sim[35,,c("TotRes","TotMig"),,i],3,sum)*1e5)
# cases
tab1[1,2:4+6] <- mulohi(apply(scen_sim[20,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,1],3,sum)/apply(scen_sim[20,,"TotRes",,1],2,sum)*1e5)
for(i in 1:7) tab1[1+i,2:4+6] <- mulohi(apply(scen_sim[35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,i],3,sum)/apply(scen_sim[35,,"TotRes",,i],2,sum)*1e5)
tab1[9,2:4+6] <- mulohi(apply(scen_sim[20,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1],3,sum)/apply(scen_sim[20,,"TotMig",,1],2,sum)*1e5)
for(i in 1:7) tab1[9+i,2:4+6] <- mulohi(apply(scen_sim[35,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,i],3,sum)/apply(scen_sim[35,,"TotMig",,i],2,sum)*1e5)
tab1[17,2:4+6] <- mulohi(apply(scen_sim[20,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes","TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1],3,sum)/apply(scen_sim[20,,c("TotRes","TotMig"),,1],3,sum)*1e5)
for(i in 1:7) tab1[17+i,2:4+6] <- mulohi(apply(scen_sim[35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes","TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,i],3,sum)/apply(scen_sim[35,,c("TotRes","TotMig"),,i],3,sum)*1e5)
# deaths
tab1[1,2:4+9] <- mulohi(apply(scen_sim[20,,"TotTbDthRes",,1],2,sum)/apply(scen_sim[20,,"TotRes",,1],2,sum)*1e5)
for(i in 1:7) tab1[1+i,2:4+9] <- mulohi(apply(scen_sim[35,,"TotTbDthRes",,i],2,sum)/apply(scen_sim[35,,"TotRes",,i],2,sum)*1e5)
tab1[9,2:4+9] <- mulohi(apply(scen_sim[20,,"TotTbDthMig",,1],2,sum)/apply(scen_sim[20,,"TotMig",,1],2,sum)*1e5)
for(i in 1:7) tab1[9+i,2:4+9] <- mulohi(apply(scen_sim[35,,"TotTbDthMig",,i],2,sum)/apply(scen_sim[35,,"TotMig",,i],2,sum)*1e5)
tab1[17,2:4+9] <- mulohi(apply(scen_sim[20,,c("TotTbDthRes","TotTbDthMig"),,1],3,sum)/apply(scen_sim[20,,c("TotRes","TotMig"),,1],3,sum)*1e5)
for(i in 1:7) tab1[17+i,2:4+9] <- mulohi(apply(scen_sim[35,,c("TotTbDthRes","TotTbDthMig"),,i],3,sum)/apply(scen_sim[35,,c("TotRes","TotMig"),,i],3,sum)*1e5)
# YLL
tab1[1,2:4+12] <- mulohi(apply(scen_sim[20,,"TotTbYllRes",,1],2,sum)/apply(scen_sim[20,,"TotRes",,1],2,sum)*1e5)
for(i in 1:7) tab1[1+i,2:4+12] <- mulohi(apply(scen_sim[35,,"TotTbYllRes",,i],2,sum)/apply(scen_sim[35,,"TotRes",,i],2,sum)*1e5)
tab1[9,2:4+12] <- mulohi(apply(scen_sim[20,,"TotTbYllMig",,1],2,sum)/apply(scen_sim[20,,"TotMig",,1],2,sum)*1e5)
for(i in 1:7) tab1[9+i,2:4+12] <- mulohi(apply(scen_sim[35,,"TotTbYllMig",,i],2,sum)/apply(scen_sim[35,,"TotMig",,i],2,sum)*1e5)
tab1[17,2:4+12] <- mulohi(apply(scen_sim[20,,c("TotTbYllRes","TotTbYllMig"),,1],3,sum)/apply(scen_sim[20,,c("TotRes","TotMig"),,1],3,sum)*1e5)
for(i in 1:7) tab1[17+i,2:4+12] <- mulohi(apply(scen_sim[35,,c("TotTbYllRes","TotTbYllMig"),,i],3,sum)/apply(scen_sim[35,,c("TotRes","TotMig"),,i],3,sum)*1e5)

###########
rownm <- paste0(rep(c("scenario1_2020",paste0("scenario",1:7,"_2035")),3),rep(c("_resident","_migrant","_all"),each=8))
colnm <- c("Transm_events_per100K","Mtb_infections_per100K","New_TB_cases_per100K","TB_deaths_per100K","YLL_to_TB_per100K")
tab1b <- as.data.frame(matrix(NA,length(rownm),length(colnm)+1))
colnames(tab1b) <- c("indicator",colnm)
tab1b$indicator <- rownm

cute <- function(zz,n){ z <- format(round(zz,n),nsmall=n); paste0(z[1]," (",z[2],", ",z[3],")") }

for(i in 1:nrow(tab1))  tab1b[i,2] <- cute(tab1[i,2:4],0)
for(i in 1:nrow(tab1))  tab1b[i,3] <- cute(tab1[i,2:4+3],0)
for(i in 1:nrow(tab1))  tab1b[i,4] <- cute(tab1[i,2:4+6],1)
for(i in 1:nrow(tab1))  tab1b[i,5] <- cute(tab1[i,2:4+9],2)
for(i in 1:nrow(tab1))  tab1b[i,6] <- cute(tab1[i,2:4+12],1)

#########################################

# cumulative outcomes
rownm <- paste0(rep(paste0("scenario",1:7),3),rep(c("_resident","_migrant","_all"),each=7))
colnm <- paste0(rep(c("Transm_events","Mtb_infections","New_TB_cases","TB_deaths","YLL_to_TB"),each=3),rep(c("_mn","_lo","_hi"),5))
tab2 <- as.data.frame(matrix(NA,length(rownm),length(colnm)+1))
colnames(tab2) <- c("indicator",colnm)
tab2$indicator <- rownm

# transmission
for(i in 1:7) tab2[0+i,2:4] <- mulohi(apply(scen_sim[20:35,,"TotTbFoiRes",,i],3,sum))
for(i in 1:7) tab2[7+i,2:4] <- mulohi(apply(scen_sim[20:35,,"TotTbFoiMig",,i],3,sum))
for(i in 1:7) tab2[14+i,2:4] <- mulohi(apply(scen_sim[20:35,,c("TotTbFoiRes","TotTbFoiMig"),,i],4,sum))
# infection
for(i in 1:7) tab2[0+i,2:4+3] <- mulohi(apply(scen_sim[20:35,,"TotTbNltRes",,i],3,sum))
for(i in 1:7) tab2[7+i,2:4+3] <- mulohi(apply(scen_sim[20:35,,"TotTbNltMig",,i],3,sum))
for(i in 1:7) tab2[14+i,2:4+3] <- mulohi(apply(scen_sim[20:35,,c("TotTbNltRes","TotTbNltMig"),,i],4,sum))
# cases
for(i in 1:7) tab2[0+i,2:4+6] <- mulohi(apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,i],4,sum))
for(i in 1:7) tab2[7+i,2:4+6] <- mulohi(apply(scen_sim[20:35,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,i],4,sum))
for(i in 1:7) tab2[14+i,2:4+6] <- mulohi(apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes","TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,i],4,sum))
# deaths
for(i in 1:7) tab2[0+i,2:4+9] <- mulohi(apply(scen_sim[20:35,,"TotTbDthRes",,i],3,sum))
for(i in 1:7) tab2[7+i,2:4+9] <- mulohi(apply(scen_sim[20:35,,"TotTbDthMig",,i],3,sum))
for(i in 1:7) tab2[14+i,2:4+9] <- mulohi(apply(scen_sim[20:35,,c("TotTbDthRes","TotTbDthMig"),,i],4,sum))
# YLL
for(i in 1:7) tab2[0+i,2:4+12] <- mulohi(apply(scen_sim[20:35,,"TotTbYllRes",,i],3,sum))
for(i in 1:7) tab2[7+i,2:4+12] <- mulohi(apply(scen_sim[20:35,,"TotTbYllMig",,i],3,sum))
for(i in 1:7) tab2[14+i,2:4+12] <- mulohi(apply(scen_sim[20:35,,c("TotTbYllRes","TotTbYllMig"),,i],4,sum))

###########
rownm <- paste0(rep(c("scenario1_2020",paste0("scenario",1:7,"_2035")),3),rep(c("_resident","_migrant","_all"),each=8))
colnm <- c("Transm_events","Mtb_infections","New_TB_cases","TB_deaths","YLL_to_TB")
tab2b <- as.data.frame(matrix(NA,length(rownm),length(colnm)+1))
colnames(tab2b) <- c("indicator",colnm)
tab2b$indicator <- rownm

for(i in 1:nrow(tab2))  tab2b[i,2] <- cute(tab2[i,2:4],0)
for(i in 1:nrow(tab2))  tab2b[i,3] <- cute(tab2[i,2:4+3],0)
for(i in 1:nrow(tab2))  tab2b[i,4] <- cute(tab2[i,2:4+6],0)
for(i in 1:nrow(tab2))  tab2b[i,5] <- cute(tab2[i,2:4+9],0)
for(i in 1:nrow(tab2))  tab2b[i,6] <- cute(tab2[i,2:4+12],0)

# cumulative outcomes (inc)
rownm <- paste0(rep(paste0("scenario",2:7),3),rep(c("_resident","_migrant","_all"),each=6))
colnm <- paste0(rep(c("Transm_events","Mtb_infections","New_TB_cases","TB_deaths","YLL_to_TB"),each=3),rep(c("_mn","_lo","_hi"),5))
tab3 <- as.data.frame(matrix(NA,length(rownm),length(colnm)+1))
colnames(tab3) <- c("indicator",colnm)
tab3$indicator <- rownm

# transmission
for(i in 1:6) tab3[0+i,2:4] <- mulohi(apply(scen_sim[20:35,,"TotTbFoiRes",,1],3,sum)-apply(scen_sim[20:35,,"TotTbFoiRes",,1+i],3,sum))
for(i in 1:6) tab3[6+i,2:4] <- mulohi(apply(scen_sim[20:35,,"TotTbFoiMig",,1],3,sum)-apply(scen_sim[20:35,,"TotTbFoiMig",,1+i],3,sum))
for(i in 1:6) tab3[12+i,2:4] <- mulohi(apply(scen_sim[20:35,,c("TotTbFoiRes","TotTbFoiMig"),,1],4,sum)-apply(scen_sim[20:35,,c("TotTbFoiRes","TotTbFoiMig"),,1+i],4,sum))
# infection
for(i in 1:6) tab3[0+i,2:4+3] <- mulohi(apply(scen_sim[20:35,,"TotTbNltRes",,1],3,sum)-apply(scen_sim[20:35,,"TotTbNltRes",,1+i],3,sum))
for(i in 1:6) tab3[6+i,2:4+3] <- mulohi(apply(scen_sim[20:35,,"TotTbNltMig",,1],3,sum)-apply(scen_sim[20:35,,"TotTbNltMig",,1+i],3,sum))
for(i in 1:6) tab3[12+i,2:4+3] <- mulohi(apply(scen_sim[20:35,,c("TotTbNltRes","TotTbNltMig"),,1],4,sum)-apply(scen_sim[20:35,,c("TotTbNltRes","TotTbNltMig"),,1+i],4,sum))
# cases
for(i in 1:6) tab3[0+i,2:4+6] <- mulohi(apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,1],4,sum)-apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,1+i],4,sum))
for(i in 1:6) tab3[6+i,2:4+6] <- mulohi(apply(scen_sim[20:35,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1],4,sum)-apply(scen_sim[20:35,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1+i],4,sum))
for(i in 1:6) tab3[12+i,2:4+6] <- mulohi(apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes","TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1],4,sum)-apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes","TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1+i],4,sum))
# deaths
for(i in 1:6) tab3[0+i,2:4+9] <- mulohi(apply(scen_sim[20:35,,"TotTbDthRes",,1],3,sum)-apply(scen_sim[20:35,,"TotTbDthRes",,1+i],3,sum))
for(i in 1:6) tab3[6+i,2:4+9] <- mulohi(apply(scen_sim[20:35,,"TotTbDthMig",,1],3,sum)-apply(scen_sim[20:35,,"TotTbDthMig",,1+i],3,sum))
for(i in 1:6) tab3[12+i,2:4+9] <- mulohi(apply(scen_sim[20:35,,c("TotTbDthRes","TotTbDthMig"),,1],4,sum)-apply(scen_sim[20:35,,c("TotTbDthRes","TotTbDthMig"),,1+i],4,sum))
# YLL
for(i in 1:6) tab3[0+i,2:4+12] <- mulohi(apply(scen_sim[20:35,,"TotTbYllRes",,1],3,sum)-apply(scen_sim[20:35,,"TotTbYllRes",,1+i],3,sum))
for(i in 1:6) tab3[6+i,2:4+12] <- mulohi(apply(scen_sim[20:35,,"TotTbYllMig",,1],3,sum)-apply(scen_sim[20:35,,"TotTbYllMig",,1+i],3,sum))
for(i in 1:6) tab3[12+i,2:4+12] <- mulohi(apply(scen_sim[20:35,,c("TotTbYllRes","TotTbYllMig"),,1],4,sum)-apply(scen_sim[20:35,,c("TotTbYllRes","TotTbYllMig"),,1+i],4,sum))

rownm <- paste0(rep(paste0("scenario",2:7,"_2035"),3),rep(c("_resident","_migrant","_all"),each=6))
colnm <- c("Transm_events","Mtb_infections","New_TB_cases","TB_deaths","YLL_to_TB")
tab3b <- as.data.frame(matrix(NA,length(rownm),length(colnm)+1))
colnames(tab3b) <- c("indicator",colnm)
tab3b$indicator <- rownm

for(i in 1:nrow(tab3))  tab3b[i,2] <- cute(tab3[i,2:4],0)
for(i in 1:nrow(tab3))  tab3b[i,3] <- cute(tab3[i,2:4+3],0)
for(i in 1:nrow(tab3))  tab3b[i,4] <- cute(tab3[i,2:4+6],0)
for(i in 1:nrow(tab3))  tab3b[i,5] <- cute(tab3[i,2:4+9],0)
for(i in 1:nrow(tab3))  tab3b[i,6] <- cute(tab3[i,2:4+12],0)

# cumulative outcomes (pct)
rownm <- paste0(rep(paste0("scenario",2:7),3),rep(c("_resident","_migrant","_all"),each=6))
colnm <- paste0(rep(c("Transm_events","Mtb_infections","New_TB_cases","TB_deaths","YLL_to_TB"),each=3),rep(c("_mn","_lo","_hi"),5))
tab4 <- as.data.frame(matrix(NA,length(rownm),length(colnm)+1))
colnames(tab4) <- c("indicator",colnm)
tab4$indicator <- rownm

# transmission
for(i in 1:6) tab4[0+i,2:4] <- mulohi(100-100*apply(scen_sim[20:35,,"TotTbFoiRes",,1+i],3,sum)/apply(scen_sim[20:35,,"TotTbFoiRes",,1],3,sum))
for(i in 1:6) tab4[6+i,2:4] <- mulohi(100-100*apply(scen_sim[20:35,,"TotTbFoiMig",,1+i],3,sum)/apply(scen_sim[20:35,,"TotTbFoiMig",,1],3,sum))
for(i in 1:6) tab4[12+i,2:4] <- mulohi(100-100*apply(scen_sim[20:35,,c("TotTbFoiRes","TotTbFoiMig"),,1+i],4,sum)/apply(scen_sim[20:35,,c("TotTbFoiRes","TotTbFoiMig"),,1],4,sum))
# infection
for(i in 1:6) tab4[0+i,2:4+3] <- mulohi(100-100*apply(scen_sim[20:35,,"TotTbNltRes",,1+i],3,sum)/apply(scen_sim[20:35,,"TotTbNltRes",,1],3,sum))
for(i in 1:6) tab4[6+i,2:4+3] <- mulohi(100-100*apply(scen_sim[20:35,,"TotTbNltMig",,1+i],3,sum)/apply(scen_sim[20:35,,"TotTbNltMig",,1],3,sum))
for(i in 1:6) tab4[12+i,2:4+3] <- mulohi(100-100*apply(scen_sim[20:35,,c("TotTbNltRes","TotTbNltMig"),,1+i],4,sum)/apply(scen_sim[20:35,,c("TotTbNltRes","TotTbNltMig"),,1],4,sum))
# cases
for(i in 1:6) tab4[0+i,2:4+6] <- mulohi(100-100*apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,1+i],4,sum)/apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes"),,1],4,sum))
for(i in 1:6) tab4[6+i,2:4+6] <- mulohi(100-100*apply(scen_sim[20:35,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1+i],4,sum)/apply(scen_sim[20:35,,c("TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1],4,sum))
for(i in 1:6) tab4[12+i,2:4+6] <- mulohi(100-100*apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes","TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1+i],4,sum)/apply(scen_sim[20:35,,c("TotIncidResMale","TotIncidResFemale","ImpCaseRes","TotIncidMigMale","TotIncidMigFemale","ImpCaseMig"),,1],4,sum))
# deaths
for(i in 1:6) tab4[0+i,2:4+9] <- mulohi(100-100*apply(scen_sim[20:35,,"TotTbDthRes",,1+i],3,sum)/apply(scen_sim[20:35,,"TotTbDthRes",,1],3,sum))
for(i in 1:6) tab4[6+i,2:4+9] <- mulohi(100-100*apply(scen_sim[20:35,,"TotTbDthMig",,1+i],3,sum)/apply(scen_sim[20:35,,"TotTbDthMig",,1],3,sum))
for(i in 1:6) tab4[12+i,2:4+9] <- mulohi(100-100*apply(scen_sim[20:35,,c("TotTbDthRes","TotTbDthMig"),,1+i],4,sum)/apply(scen_sim[20:35,,c("TotTbDthRes","TotTbDthMig"),,1],4,sum))
# YLL
for(i in 1:6) tab4[0+i,2:4+12] <- mulohi(100-100*apply(scen_sim[20:35,,"TotTbYllRes",,1+i],3,sum)/apply(scen_sim[20:35,,"TotTbYllRes",,1],3,sum))
for(i in 1:6) tab4[6+i,2:4+12] <- mulohi(100-100*apply(scen_sim[20:35,,"TotTbYllMig",,1+i],3,sum)/apply(scen_sim[20:35,,"TotTbYllMig",,1],3,sum))
for(i in 1:6) tab4[12+i,2:4+12] <- mulohi(100-100*apply(scen_sim[20:35,,c("TotTbYllRes","TotTbYllMig"),,1+i],4,sum)/apply(scen_sim[20:35,,c("TotTbYllRes","TotTbYllMig"),,1],4,sum))

rownm <- paste0(rep(paste0("scenario",2:7,"_2035"),3),rep(c("_resident","_migrant","_all"),each=6))
colnm <- c("Transm_events","Mtb_infections","New_TB_cases","TB_deaths","YLL_to_TB")
tab4b <- as.data.frame(matrix(NA,length(rownm),length(colnm)+1))
colnames(tab4b) <- c("indicator",colnm)
tab4b$indicator <- rownm

for(i in 1:nrow(tab4))  tab4b[i,2] <- cute(tab4[i,2:4],1)
for(i in 1:nrow(tab4))  tab4b[i,3] <- cute(tab4[i,2:4+3],1)
for(i in 1:nrow(tab4))  tab4b[i,4] <- cute(tab4[i,2:4+6],1)
for(i in 1:nrow(tab4))  tab4b[i,5] <- cute(tab4[i,2:4+9],1)
for(i in 1:nrow(tab4))  tab4b[i,6] <- cute(tab4[i,2:4+12],1)

#######
tab_suffix <- "Tab_Shanghai_manuscript_11-22-2019"

write.csv(tab1,file=paste0(tab_suffix, "_rate_outcomes.csv"),row.names=F)
write.csv(tab1b,file=paste0(tab_suffix, "_rate_outcomes_formatted.csv"),row.names=F)
write.csv(tab2,file=paste0(tab_suffix, "_cum_outcomes.csv"),row.names=F)
write.csv(tab2b,file=paste0(tab_suffix, "_cum_outcomes_formatted.csv"),row.names=F)
write.csv(tab3,file=paste0(tab_suffix, "_inc_cum_outcomes.csv"),row.names=F)
write.csv(tab3b,file=paste0(tab_suffix, "_inc_cum_outcomes_formatted.csv"),row.names=F)
write.csv(tab4,file=paste0(tab_suffix, "_pct_cum_outcomes.csv"),row.names=F)
write.csv(tab4b,file=paste0(tab_suffix, "_pct_cum_outcomes_formatted.csv"),row.names=F)




